
# Ensures that the stubs are picked up - thanks, numpy project
from depthai import (
    node as node,
)

import typing
json = dict
from pathlib import Path
from typing import Set, Type, TypeVar
T = TypeVar('T')
from typing import Any, Callable, ClassVar, Dict, Iterator, List, Optional, Tuple

from typing import overload
import datetime
import numpy
X_LINK_ALREADY_OPEN: XLinkError_t
X_LINK_ANY_PLATFORM: XLinkPlatform
X_LINK_ANY_PROTOCOL: XLinkProtocol
X_LINK_ANY_STATE: XLinkDeviceState
X_LINK_BOOTED: XLinkDeviceState
X_LINK_BOOTED_NON_EXCLUSIVE: XLinkDeviceState
X_LINK_BOOTLOADER: XLinkDeviceState
X_LINK_COMMUNICATION_FAIL: XLinkError_t
X_LINK_COMMUNICATION_NOT_OPEN: XLinkError_t
X_LINK_COMMUNICATION_UNKNOWN_ERROR: XLinkError_t
X_LINK_DEVICE_ALREADY_IN_USE: XLinkError_t
X_LINK_DEVICE_NOT_FOUND: XLinkError_t
X_LINK_ERROR: XLinkError_t
X_LINK_FLASH_BOOTED: XLinkDeviceState
X_LINK_GATE: XLinkDeviceState
X_LINK_GATE_BOOTED: XLinkDeviceState
X_LINK_INIT_PCIE_ERROR: XLinkError_t
X_LINK_INIT_TCP_IP_ERROR: XLinkError_t
X_LINK_INIT_USB_ERROR: XLinkError_t
X_LINK_INSUFFICIENT_PERMISSIONS: XLinkError_t
X_LINK_IPC: XLinkProtocol
X_LINK_MYRIAD_2: XLinkPlatform
X_LINK_MYRIAD_X: XLinkPlatform
X_LINK_NMB_OF_PROTOCOLS: XLinkProtocol
X_LINK_NOT_IMPLEMENTED: XLinkError_t
X_LINK_OUT_OF_MEMORY: XLinkError_t
X_LINK_PCIE: XLinkProtocol
X_LINK_RVC3: XLinkPlatform
X_LINK_SUCCESS: XLinkError_t
X_LINK_TCP_IP: XLinkProtocol
X_LINK_TIMEOUT: XLinkError_t
X_LINK_UNBOOTED: XLinkDeviceState
X_LINK_USB_CDC: XLinkProtocol
X_LINK_USB_VSC: XLinkProtocol

class ADatatype:
    def __init__(self) -> None: ...

class AprilTag:
    bottomLeft: Point2f
    bottomRight: Point2f
    decisionMargin: float
    hamming: int
    id: int
    topLeft: Point2f
    topRight: Point2f
    def __init__(self) -> None: ...

class AprilTagConfig(Buffer):
    class Family:
        __members__: ClassVar[dict] = ...  # read-only
        TAG_16H5: ClassVar[AprilTagConfig.Family] = ...
        TAG_25H9: ClassVar[AprilTagConfig.Family] = ...
        TAG_36H10: ClassVar[AprilTagConfig.Family] = ...
        TAG_36H11: ClassVar[AprilTagConfig.Family] = ...
        TAG_CIR21H7: ClassVar[AprilTagConfig.Family] = ...
        TAG_STAND41H12: ClassVar[AprilTagConfig.Family] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class QuadThresholds:
        criticalDegree: float
        deglitch: bool
        maxLineFitMse: float
        maxNmaxima: int
        minClusterPixels: int
        minWhiteBlackDiff: int
        def __init__(self) -> None: ...
    decodeSharpening: float
    family: AprilTagConfig.Family
    maxHammingDistance: int
    quadDecimate: int
    quadSigma: float
    quadThresholds: AprilTagConfig.QuadThresholds
    refineEdges: bool
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def setFamily(self, family: AprilTagConfig.Family) -> AprilTagConfig: ...

class AprilTagProperties:
    initialConfig: AprilTagConfig
    inputConfigSync: bool
    def __init__(self, *args, **kwargs) -> None: ...

class AprilTags(Buffer):
    aprilTags: List[AprilTag]
    def __init__(self) -> None: ...
    def getSequenceNum(self) -> int: ...
    def getTimestamp(self) -> datetime.timedelta: ...
    def getTimestampDevice(self) -> datetime.timedelta: ...

class Asset:
    alignment: int
    data: numpy.ndarray[numpy.uint8]
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: str) -> None: ...
    @property
    def key(self) -> str: ...

class AssetManager:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: str) -> None: ...
    def addExisting(self, assets: List[Asset]) -> None: ...
    @overload
    def get(self, key: str) -> Asset: ...
    @overload
    def get(self, key: str) -> Asset: ...
    @overload
    def getAll(self) -> List[Asset]: ...
    @overload
    def getAll(self) -> List[Asset]: ...
    def getRootPath(self) -> str: ...
    def remove(self, key: str) -> None: ...
    @overload
    def set(self, asset: Asset) -> Asset: ...
    @overload
    def set(self, key: str, asset: Asset) -> Asset: ...
    @overload
    def set(self, key: str, path: Path, alignment: int = ...) -> Asset: ...
    @overload
    def set(self, key: str, data: List[int], alignment: int = ...) -> Asset: ...
    def size(self) -> int: ...

class BenchmarkReport(Buffer):
    def __init__(self) -> None: ...
    @property
    def averageLatency(self) -> float: ...
    @property
    def fps(self) -> float: ...
    @property
    def latencies(self) -> List[float]: ...
    @property
    def numMessagesReceived(self) -> float: ...
    @property
    def timeTotal(self) -> float: ...

class BoardConfig:
    class GPIO:
        class Direction:
            __members__: ClassVar[dict] = ...  # read-only
            INPUT: ClassVar[BoardConfig.GPIO.Direction] = ...
            OUTPUT: ClassVar[BoardConfig.GPIO.Direction] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class Drive:
            __members__: ClassVar[dict] = ...  # read-only
            MA_12: ClassVar[BoardConfig.GPIO.Drive] = ...
            MA_2: ClassVar[BoardConfig.GPIO.Drive] = ...
            MA_4: ClassVar[BoardConfig.GPIO.Drive] = ...
            MA_8: ClassVar[BoardConfig.GPIO.Drive] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class Level:
            __members__: ClassVar[dict] = ...  # read-only
            HIGH: ClassVar[BoardConfig.GPIO.Level] = ...
            LOW: ClassVar[BoardConfig.GPIO.Level] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class Mode:
            __members__: ClassVar[dict] = ...  # read-only
            ALT_MODE_0: ClassVar[BoardConfig.GPIO.Mode] = ...
            ALT_MODE_1: ClassVar[BoardConfig.GPIO.Mode] = ...
            ALT_MODE_2: ClassVar[BoardConfig.GPIO.Mode] = ...
            ALT_MODE_3: ClassVar[BoardConfig.GPIO.Mode] = ...
            ALT_MODE_4: ClassVar[BoardConfig.GPIO.Mode] = ...
            ALT_MODE_5: ClassVar[BoardConfig.GPIO.Mode] = ...
            ALT_MODE_6: ClassVar[BoardConfig.GPIO.Mode] = ...
            DIRECT: ClassVar[BoardConfig.GPIO.Mode] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class Pull:
            __members__: ClassVar[dict] = ...  # read-only
            BUS_KEEPER: ClassVar[BoardConfig.GPIO.Pull] = ...
            NO_PULL: ClassVar[BoardConfig.GPIO.Pull] = ...
            PULL_DOWN: ClassVar[BoardConfig.GPIO.Pull] = ...
            PULL_UP: ClassVar[BoardConfig.GPIO.Pull] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        ALT_MODE_0: ClassVar[BoardConfig.GPIO.Mode] = ...
        ALT_MODE_1: ClassVar[BoardConfig.GPIO.Mode] = ...
        ALT_MODE_2: ClassVar[BoardConfig.GPIO.Mode] = ...
        ALT_MODE_3: ClassVar[BoardConfig.GPIO.Mode] = ...
        ALT_MODE_4: ClassVar[BoardConfig.GPIO.Mode] = ...
        ALT_MODE_5: ClassVar[BoardConfig.GPIO.Mode] = ...
        ALT_MODE_6: ClassVar[BoardConfig.GPIO.Mode] = ...
        BUS_KEEPER: ClassVar[BoardConfig.GPIO.Pull] = ...
        DIRECT: ClassVar[BoardConfig.GPIO.Mode] = ...
        HIGH: ClassVar[BoardConfig.GPIO.Level] = ...
        INPUT: ClassVar[BoardConfig.GPIO.Direction] = ...
        LOW: ClassVar[BoardConfig.GPIO.Level] = ...
        MA_12: ClassVar[BoardConfig.GPIO.Drive] = ...
        MA_2: ClassVar[BoardConfig.GPIO.Drive] = ...
        MA_4: ClassVar[BoardConfig.GPIO.Drive] = ...
        MA_8: ClassVar[BoardConfig.GPIO.Drive] = ...
        NO_PULL: ClassVar[BoardConfig.GPIO.Pull] = ...
        OUTPUT: ClassVar[BoardConfig.GPIO.Direction] = ...
        PULL_DOWN: ClassVar[BoardConfig.GPIO.Pull] = ...
        PULL_UP: ClassVar[BoardConfig.GPIO.Pull] = ...
        direction: BoardConfig.GPIO.Direction
        drive: BoardConfig.GPIO.Drive
        level: BoardConfig.GPIO.Level
        mode: BoardConfig.GPIO.Mode
        pull: BoardConfig.GPIO.Pull
        schmitt: bool
        slewFast: bool
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: BoardConfig.GPIO.Direction) -> None: ...
        @overload
        def __init__(self, arg0: BoardConfig.GPIO.Direction, arg1: BoardConfig.GPIO.Level) -> None: ...
        @overload
        def __init__(self, arg0: BoardConfig.GPIO.Direction, arg1: BoardConfig.GPIO.Level, arg2: BoardConfig.GPIO.Pull) -> None: ...
        @overload
        def __init__(self, arg0: BoardConfig.GPIO.Direction, arg1: BoardConfig.GPIO.Mode) -> None: ...
        @overload
        def __init__(self, arg0: BoardConfig.GPIO.Direction, arg1: BoardConfig.GPIO.Mode, arg2: BoardConfig.GPIO.Pull) -> None: ...

    class GPIOMap:
        def __init__(self) -> None: ...
        def items(self) -> BoardConfig.ItemsView_GPIOMap: ...
        def keys(self) -> BoardConfig.KeysView_GPIOMap: ...
        def values(self) -> BoardConfig.ValuesView_GPIOMap: ...
        def __bool__(self) -> bool: ...
        @overload
        def __contains__(self, arg0: int) -> bool: ...
        @overload
        def __contains__(self, arg0: object) -> bool: ...
        def __delitem__(self, arg0: int) -> None: ...
        def __getitem__(self, arg0: int) -> BoardConfig.GPIO: ...
        def __iter__(self) -> Iterator: ...
        def __len__(self) -> int: ...
        def __setitem__(self, arg0: int, arg1: BoardConfig.GPIO) -> None: ...

    class ItemsView_GPIOMap:
        def __init__(self, *args, **kwargs) -> None: ...
        def __iter__(self) -> Iterator: ...
        def __len__(self) -> int: ...

    class ItemsView_UARTMap:
        def __init__(self, *args, **kwargs) -> None: ...
        def __iter__(self) -> Iterator: ...
        def __len__(self) -> int: ...

    class KeysView_GPIOMap:
        def __init__(self, *args, **kwargs) -> None: ...
        @overload
        def __contains__(self, arg0: int) -> bool: ...
        @overload
        def __contains__(self, arg0: object) -> bool: ...
        def __iter__(self) -> Iterator: ...
        def __len__(self) -> int: ...

    class KeysView_UARTMap:
        def __init__(self, *args, **kwargs) -> None: ...
        @overload
        def __contains__(self, arg0: int) -> bool: ...
        @overload
        def __contains__(self, arg0: object) -> bool: ...
        def __iter__(self) -> Iterator: ...
        def __len__(self) -> int: ...

    class Network:
        mtu: int
        xlinkTcpNoDelay: bool
        def __init__(self) -> None: ...

    class UART:
        tmp: int
        def __init__(self) -> None: ...

    class UARTMap:
        def __init__(self) -> None: ...
        def items(self) -> BoardConfig.ItemsView_UARTMap: ...
        def keys(self) -> BoardConfig.KeysView_UARTMap: ...
        def values(self) -> BoardConfig.ValuesView_UARTMap: ...
        def __bool__(self) -> bool: ...
        @overload
        def __contains__(self, arg0: int) -> bool: ...
        @overload
        def __contains__(self, arg0: object) -> bool: ...
        def __delitem__(self, arg0: int) -> None: ...
        def __getitem__(self, arg0: int) -> BoardConfig.UART: ...
        def __iter__(self) -> Iterator: ...
        def __len__(self) -> int: ...
        def __setitem__(self, arg0: int, arg1: BoardConfig.UART) -> None: ...

    class USB:
        flashBootedPid: int
        flashBootedVid: int
        manufacturer: str
        maxSpeed: UsbSpeed
        pid: int
        productName: str
        vid: int
        def __init__(self) -> None: ...

    class UVC:
        cameraName: str
        enable: bool
        frameType: ImgFrame.Type
        height: int
        width: int
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: int, arg1: int) -> None: ...

    class ValuesView_GPIOMap:
        def __init__(self, *args, **kwargs) -> None: ...
        def __iter__(self) -> Iterator: ...
        def __len__(self) -> int: ...

    class ValuesView_UARTMap:
        def __init__(self, *args, **kwargs) -> None: ...
        def __iter__(self) -> Iterator: ...
        def __len__(self) -> int: ...
    emmc: Optional[bool]
    gpio: BoardConfig.GPIOMap
    logDevicePrints: Optional[bool]
    logPath: Optional[str]
    logSizeMax: Optional[int]
    logVerbosity: Optional[LogLevel]
    mipi4LaneRgb: Optional[bool]
    network: BoardConfig.Network
    pcieInternalClock: Optional[bool]
    sysctl: List[str]
    uart: BoardConfig.UARTMap
    usb: BoardConfig.USB
    usb3PhyInternalClock: Optional[bool]
    uvc: Optional[BoardConfig.UVC]
    watchdogInitialDelayMs: Optional[int]
    watchdogTimeoutMs: Optional[int]
    def __init__(self) -> None: ...

class Buffer(ADatatype):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: int) -> None: ...
    def getData(self) -> numpy.ndarray[numpy.uint8]: ...
    def getSequenceNum(self) -> int: ...
    def getTimestamp(self) -> datetime.timedelta: ...
    def getTimestampDevice(self) -> datetime.timedelta: ...
    @overload
    def setData(self, arg0: List[int]) -> None: ...
    @overload
    def setData(self, arg0: numpy.ndarray[numpy.uint8]) -> None: ...
    @overload
    def setData(self, arg0: buffer) -> None: ...
    def setSequenceNum(self, arg0: int) -> None: ...
    def setTimestamp(self, arg0: datetime.timedelta) -> None: ...
    def setTimestampDevice(self, arg0: datetime.timedelta) -> None: ...

class CalibrationHandler:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Path) -> None: ...
    @overload
    def __init__(self, arg0: Path, arg1: Path) -> None: ...
    @overload
    def __init__(self, arg0: EepromData) -> None: ...
    def eepromToJson(self) -> json: ...
    def eepromToJsonFile(self, destPath: Path) -> bool: ...
    @classmethod
    def fromJson(cls, arg0: json) -> CalibrationHandler: ...
    def getBaselineDistance(self, cam1: CameraBoardSocket = ..., cam2: CameraBoardSocket = ..., useSpecTranslation: bool = ...) -> float: ...
    def getCameraExtrinsics(self, srcCamera: CameraBoardSocket, dstCamera: CameraBoardSocket, useSpecTranslation: bool = ...) -> List[List[float]]: ...
    @overload
    def getCameraIntrinsics(self, cameraId: CameraBoardSocket, resizeWidth: int = ..., resizeHeight: int = ..., topLeftPixelId: Point2f = ..., bottomRightPixelId: Point2f = ..., keepAspectRatio: bool = ...) -> List[List[float]]: ...
    @overload
    def getCameraIntrinsics(self, cameraId: CameraBoardSocket, destShape: Size2f, topLeftPixelId: Point2f = ..., bottomRightPixelId: Point2f = ..., keepAspectRatio: bool = ...) -> List[List[float]]: ...
    @overload
    def getCameraIntrinsics(self, cameraId: CameraBoardSocket, destShape: Tuple[int,int], topLeftPixelId: Point2f = ..., bottomRightPixelId: Point2f = ..., keepAspectRatio: bool = ...) -> List[List[float]]: ...
    def getCameraRotationMatrix(self, srcCamera: CameraBoardSocket, dstCamera: CameraBoardSocket) -> List[List[float]]: ...
    def getCameraToImuExtrinsics(self, cameraId: CameraBoardSocket, useSpecTranslation: bool = ...) -> List[List[float]]: ...
    def getCameraTranslationVector(self, srcCamera: CameraBoardSocket, dstCamera: CameraBoardSocket, useSpecTranslation: bool = ...) -> List[float]: ...
    def getDefaultIntrinsics(self, cameraId: CameraBoardSocket) -> Tuple[List[List[float]],int,int]: ...
    def getDistortionCoefficients(self, cameraId: CameraBoardSocket) -> List[float]: ...
    def getDistortionModel(self, cameraId: CameraBoardSocket) -> CameraModel: ...
    def getEepromData(self) -> EepromData: ...
    def getFov(self, cameraId: CameraBoardSocket, useSpec: bool = ...) -> float: ...
    def getImuToCameraExtrinsics(self, cameraId: CameraBoardSocket, useSpecTranslation: bool = ...) -> List[List[float]]: ...
    def getLensPosition(self, cameraId: CameraBoardSocket) -> int: ...
    def getStereoLeftCameraId(self) -> CameraBoardSocket: ...
    def getStereoLeftRectificationRotation(self) -> List[List[float]]: ...
    def getStereoRightCameraId(self) -> CameraBoardSocket: ...
    def getStereoRightRectificationRotation(self) -> List[List[float]]: ...
    @overload
    def setBoardInfo(self, boardName: str, boardRev: str) -> None: ...
    @overload
    def setBoardInfo(self, productName: str, boardName: str, boardRev: str, boardConf: str, hardwareConf: str, batchName: str, batchTime: int, boardOptions: int, boardCustom: str = ...) -> None: ...
    @overload
    def setBoardInfo(self, deviceName: str, productName: str, boardName: str, boardRev: str, boardConf: str, hardwareConf: str, batchName: str, batchTime: int, boardOptions: int, boardCustom: str = ...) -> None: ...
    def setCameraExtrinsics(self, srcCameraId: CameraBoardSocket, destCameraId: CameraBoardSocket, rotationMatrix: List[List[float]], translation: List[float], specTranslation: List[float] = ...) -> None: ...
    @overload
    def setCameraIntrinsics(self, cameraId: CameraBoardSocket, intrinsics: List[List[float]], frameSize: Size2f) -> None: ...
    @overload
    def setCameraIntrinsics(self, cameraId: CameraBoardSocket, intrinsics: List[List[float]], width: int, height: int) -> None: ...
    @overload
    def setCameraIntrinsics(self, cameraId: CameraBoardSocket, intrinsics: List[List[float]], frameSize: Tuple[int,int]) -> None: ...
    def setCameraType(self, cameraId: CameraBoardSocket, cameraModel: CameraModel) -> None: ...
    def setDeviceName(self, deviceName: str) -> None: ...
    def setDistortionCoefficients(self, cameraId: CameraBoardSocket, distortionCoefficients: List[float]) -> None: ...
    def setFov(self, cameraId: CameraBoardSocket, hfov: float) -> None: ...
    def setImuExtrinsics(self, destCameraId: CameraBoardSocket, rotationMatrix: List[List[float]], translation: List[float], specTranslation: List[float] = ...) -> None: ...
    def setLensPosition(self, cameraId: CameraBoardSocket, lensPosition: int) -> None: ...
    def setProductName(self, productName: str) -> None: ...
    def setStereoLeft(self, cameraId: CameraBoardSocket, rectifiedRotation: List[List[float]]) -> None: ...
    def setStereoRight(self, cameraId: CameraBoardSocket, rectifiedRotation: List[List[float]]) -> None: ...

class CameraBoardSocket:
    CENTER: ClassVar[CameraBoardSocket] = ...  # read-only
    LEFT: ClassVar[CameraBoardSocket] = ...  # read-only
    RGB: ClassVar[CameraBoardSocket] = ...  # read-only
    RIGHT: ClassVar[CameraBoardSocket] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    AUTO: ClassVar[CameraBoardSocket] = ...
    CAM_A: ClassVar[CameraBoardSocket] = ...
    CAM_B: ClassVar[CameraBoardSocket] = ...
    CAM_C: ClassVar[CameraBoardSocket] = ...
    CAM_D: ClassVar[CameraBoardSocket] = ...
    CAM_E: ClassVar[CameraBoardSocket] = ...
    CAM_F: ClassVar[CameraBoardSocket] = ...
    CAM_G: ClassVar[CameraBoardSocket] = ...
    CAM_H: ClassVar[CameraBoardSocket] = ...
    VERTICAL: ClassVar[CameraBoardSocket] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class CameraControl(Buffer):
    class AntiBandingMode:
        __members__: ClassVar[dict] = ...  # read-only
        AUTO: ClassVar[CameraControl.AntiBandingMode] = ...
        MAINS_50_HZ: ClassVar[CameraControl.AntiBandingMode] = ...
        MAINS_60_HZ: ClassVar[CameraControl.AntiBandingMode] = ...
        OFF: ClassVar[CameraControl.AntiBandingMode] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class AutoFocusMode:
        __members__: ClassVar[dict] = ...  # read-only
        AUTO: ClassVar[CameraControl.AutoFocusMode] = ...
        CONTINUOUS_PICTURE: ClassVar[CameraControl.AutoFocusMode] = ...
        CONTINUOUS_VIDEO: ClassVar[CameraControl.AutoFocusMode] = ...
        EDOF: ClassVar[CameraControl.AutoFocusMode] = ...
        MACRO: ClassVar[CameraControl.AutoFocusMode] = ...
        OFF: ClassVar[CameraControl.AutoFocusMode] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class AutoWhiteBalanceMode:
        __members__: ClassVar[dict] = ...  # read-only
        AUTO: ClassVar[CameraControl.AutoWhiteBalanceMode] = ...
        CLOUDY_DAYLIGHT: ClassVar[CameraControl.AutoWhiteBalanceMode] = ...
        DAYLIGHT: ClassVar[CameraControl.AutoWhiteBalanceMode] = ...
        FLUORESCENT: ClassVar[CameraControl.AutoWhiteBalanceMode] = ...
        INCANDESCENT: ClassVar[CameraControl.AutoWhiteBalanceMode] = ...
        OFF: ClassVar[CameraControl.AutoWhiteBalanceMode] = ...
        SHADE: ClassVar[CameraControl.AutoWhiteBalanceMode] = ...
        TWILIGHT: ClassVar[CameraControl.AutoWhiteBalanceMode] = ...
        WARM_FLUORESCENT: ClassVar[CameraControl.AutoWhiteBalanceMode] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class CaptureIntent:
        __members__: ClassVar[dict] = ...  # read-only
        CUSTOM: ClassVar[CameraControl.CaptureIntent] = ...
        PREVIEW: ClassVar[CameraControl.CaptureIntent] = ...
        STILL_CAPTURE: ClassVar[CameraControl.CaptureIntent] = ...
        VIDEO_RECORD: ClassVar[CameraControl.CaptureIntent] = ...
        VIDEO_SNAPSHOT: ClassVar[CameraControl.CaptureIntent] = ...
        ZERO_SHUTTER_LAG: ClassVar[CameraControl.CaptureIntent] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class Command:
        __members__: ClassVar[dict] = ...  # read-only
        AE_AUTO: ClassVar[CameraControl.Command] = ...
        AE_LOCK: ClassVar[CameraControl.Command] = ...
        AE_MANUAL: ClassVar[CameraControl.Command] = ...
        AE_REGION: ClassVar[CameraControl.Command] = ...
        AE_TARGET_FPS_RANGE: ClassVar[CameraControl.Command] = ...
        AF_MODE: ClassVar[CameraControl.Command] = ...
        AF_REGION: ClassVar[CameraControl.Command] = ...
        AF_TRIGGER: ClassVar[CameraControl.Command] = ...
        ANTIBANDING_MODE: ClassVar[CameraControl.Command] = ...
        AWB_LOCK: ClassVar[CameraControl.Command] = ...
        AWB_MODE: ClassVar[CameraControl.Command] = ...
        BRIGHTNESS: ClassVar[CameraControl.Command] = ...
        CAPTURE_INTENT: ClassVar[CameraControl.Command] = ...
        CHROMA_DENOISE: ClassVar[CameraControl.Command] = ...
        CONTRAST: ClassVar[CameraControl.Command] = ...
        CONTROL_MODE: ClassVar[CameraControl.Command] = ...
        CUSTOM_CAPTURE: ClassVar[CameraControl.Command] = ...
        CUSTOM_CAPT_MODE: ClassVar[CameraControl.Command] = ...
        CUSTOM_EXP_BRACKETS: ClassVar[CameraControl.Command] = ...
        CUSTOM_USECASE: ClassVar[CameraControl.Command] = ...
        EFFECT_MODE: ClassVar[CameraControl.Command] = ...
        EXPOSURE_COMPENSATION: ClassVar[CameraControl.Command] = ...
        FRAME_DURATION: ClassVar[CameraControl.Command] = ...
        LUMA_DENOISE: ClassVar[CameraControl.Command] = ...
        MOVE_LENS: ClassVar[CameraControl.Command] = ...
        NOISE_REDUCTION_STRENGTH: ClassVar[CameraControl.Command] = ...
        RESOLUTION: ClassVar[CameraControl.Command] = ...
        SATURATION: ClassVar[CameraControl.Command] = ...
        SCENE_MODE: ClassVar[CameraControl.Command] = ...
        SENSITIVITY: ClassVar[CameraControl.Command] = ...
        SHARPNESS: ClassVar[CameraControl.Command] = ...
        START_STREAM: ClassVar[CameraControl.Command] = ...
        STILL_CAPTURE: ClassVar[CameraControl.Command] = ...
        STOP_STREAM: ClassVar[CameraControl.Command] = ...
        STREAM_FORMAT: ClassVar[CameraControl.Command] = ...
        WB_COLOR_TEMP: ClassVar[CameraControl.Command] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class ControlMode:
        __members__: ClassVar[dict] = ...  # read-only
        AUTO: ClassVar[CameraControl.ControlMode] = ...
        OFF: ClassVar[CameraControl.ControlMode] = ...
        USE_SCENE_MODE: ClassVar[CameraControl.ControlMode] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class EffectMode:
        __members__: ClassVar[dict] = ...  # read-only
        AQUA: ClassVar[CameraControl.EffectMode] = ...
        BLACKBOARD: ClassVar[CameraControl.EffectMode] = ...
        MONO: ClassVar[CameraControl.EffectMode] = ...
        NEGATIVE: ClassVar[CameraControl.EffectMode] = ...
        OFF: ClassVar[CameraControl.EffectMode] = ...
        POSTERIZE: ClassVar[CameraControl.EffectMode] = ...
        SEPIA: ClassVar[CameraControl.EffectMode] = ...
        SOLARIZE: ClassVar[CameraControl.EffectMode] = ...
        WHITEBOARD: ClassVar[CameraControl.EffectMode] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class FrameSyncMode:
        __members__: ClassVar[dict] = ...  # read-only
        INPUT: ClassVar[CameraControl.FrameSyncMode] = ...
        OFF: ClassVar[CameraControl.FrameSyncMode] = ...
        OUTPUT: ClassVar[CameraControl.FrameSyncMode] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class SceneMode:
        __members__: ClassVar[dict] = ...  # read-only
        ACTION: ClassVar[CameraControl.SceneMode] = ...
        BARCODE: ClassVar[CameraControl.SceneMode] = ...
        BEACH: ClassVar[CameraControl.SceneMode] = ...
        CANDLELIGHT: ClassVar[CameraControl.SceneMode] = ...
        FACE_PRIORITY: ClassVar[CameraControl.SceneMode] = ...
        FIREWORKS: ClassVar[CameraControl.SceneMode] = ...
        LANDSCAPE: ClassVar[CameraControl.SceneMode] = ...
        NIGHT: ClassVar[CameraControl.SceneMode] = ...
        NIGHT_PORTRAIT: ClassVar[CameraControl.SceneMode] = ...
        PARTY: ClassVar[CameraControl.SceneMode] = ...
        PORTRAIT: ClassVar[CameraControl.SceneMode] = ...
        SNOW: ClassVar[CameraControl.SceneMode] = ...
        SPORTS: ClassVar[CameraControl.SceneMode] = ...
        STEADYPHOTO: ClassVar[CameraControl.SceneMode] = ...
        SUNSET: ClassVar[CameraControl.SceneMode] = ...
        THEATRE: ClassVar[CameraControl.SceneMode] = ...
        UNSUPPORTED: ClassVar[CameraControl.SceneMode] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    aeLockMode: bool
    aeMaxExposureTimeUs: int
    afRegion: Any
    antiBandingMode: CameraControl.AntiBandingMode
    autoFocusMode: CameraControl.AutoFocusMode
    awbLockMode: bool
    awbMode: CameraControl.AutoWhiteBalanceMode
    brightness: int
    captureIntent: CameraControl.CaptureIntent
    chromaDenoise: int
    cmdMask: int
    contrast: int
    controlMode: CameraControl.ControlMode
    effectMode: CameraControl.EffectMode
    expCompensation: int
    expManual: Any
    lensPosition: int
    lumaDenoise: int
    saturation: int
    sceneMode: CameraControl.SceneMode
    sharpness: int
    wbColorTemp: int
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def clearCommand(self, arg0: CameraControl.Command) -> None: ...
    def clearMiscControls(self) -> None: ...
    def getCaptureStill(self) -> bool: ...
    def getCommand(self, arg0: CameraControl.Command) -> bool: ...
    def getExposureTime(self) -> datetime.timedelta: ...
    def getLensPosition(self) -> int: ...
    def getLensPositionRaw(self) -> float: ...
    def getMiscControls(self) -> List[Tuple[str,str]]: ...
    def getSensitivity(self) -> int: ...
    def setAntiBandingMode(self, mode: CameraControl.AntiBandingMode) -> CameraControl: ...
    def setAutoExposureCompensation(self, compensation: int) -> CameraControl: ...
    def setAutoExposureEnable(self) -> CameraControl: ...
    @overload
    def setAutoExposureLimit(self, maxExposureTimeUs: int) -> CameraControl: ...
    @overload
    def setAutoExposureLimit(self, maxExposureTime: datetime.timedelta) -> CameraControl: ...
    def setAutoExposureLock(self, lock: bool) -> CameraControl: ...
    def setAutoExposureRegion(self, startX: int, startY: int, width: int, height: int) -> CameraControl: ...
    def setAutoFocusLensRange(self, infinityPosition: int, macroPosition: int) -> CameraControl: ...
    def setAutoFocusMode(self, mode: CameraControl.AutoFocusMode) -> CameraControl: ...
    def setAutoFocusRegion(self, startX: int, startY: int, width: int, height: int) -> CameraControl: ...
    def setAutoFocusTrigger(self) -> CameraControl: ...
    def setAutoWhiteBalanceLock(self, lock: bool) -> CameraControl: ...
    def setAutoWhiteBalanceMode(self, mode: CameraControl.AutoWhiteBalanceMode) -> CameraControl: ...
    def setBrightness(self, value: int) -> CameraControl: ...
    def setCaptureIntent(self, mode: CameraControl.CaptureIntent) -> CameraControl: ...
    def setCaptureStill(self, capture: bool) -> CameraControl: ...
    def setChromaDenoise(self, value: int) -> CameraControl: ...
    def setCommand(self, arg0: CameraControl.Command, arg1: bool) -> None: ...
    def setContrast(self, value: int) -> CameraControl: ...
    def setControlMode(self, mode: CameraControl.ControlMode) -> CameraControl: ...
    def setEffectMode(self, mode: CameraControl.EffectMode) -> CameraControl: ...
    def setExternalTrigger(self, numFramesBurst: int, numFramesDiscard: int) -> CameraControl: ...
    def setFrameSyncMode(self, mode: CameraControl.FrameSyncMode) -> CameraControl: ...
    def setLumaDenoise(self, value: int) -> CameraControl: ...
    @overload
    def setManualExposure(self, exposureTimeUs: int, sensitivityIso: int) -> CameraControl: ...
    @overload
    def setManualExposure(self, exposureTime: datetime.timedelta, sensitivityIso: int) -> CameraControl: ...
    def setManualFocus(self, lensPosition: int) -> CameraControl: ...
    def setManualFocusRaw(self, lensPositionRaw: float) -> CameraControl: ...
    def setManualWhiteBalance(self, colorTemperatureK: int) -> CameraControl: ...
    @overload
    def setMisc(self, control: str, value: str) -> CameraControl: ...
    @overload
    def setMisc(self, control: str, value: int) -> CameraControl: ...
    @overload
    def setMisc(self, control: str, value: float) -> CameraControl: ...
    def setSaturation(self, value: int) -> CameraControl: ...
    def setSceneMode(self, mode: CameraControl.SceneMode) -> CameraControl: ...
    def setSharpness(self, value: int) -> CameraControl: ...
    def setStartStreaming(self) -> CameraControl: ...
    def setStopStreaming(self) -> CameraControl: ...
    def setStrobeDisable(self) -> CameraControl: ...
    def setStrobeExternal(self, gpioNumber: int, activeLevel: int) -> CameraControl: ...
    def setStrobeSensor(self, activeLevel: int) -> CameraControl: ...

class CameraExposureOffset:
    __members__: ClassVar[dict] = ...  # read-only
    END: ClassVar[CameraExposureOffset] = ...
    MIDDLE: ClassVar[CameraExposureOffset] = ...
    START: ClassVar[CameraExposureOffset] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class CameraFeatures:
    calibrationResolution: Optional[CameraSensorConfig]
    configs: List[CameraSensorConfig]
    hasAutofocus: bool
    hasAutofocusIC: bool
    height: int
    name: str
    orientation: CameraImageOrientation
    sensorName: str
    socket: CameraBoardSocket
    supportedTypes: List[CameraSensorType]
    width: int
    def __init__(self) -> None: ...

class CameraImageOrientation:
    __members__: ClassVar[dict] = ...  # read-only
    AUTO: ClassVar[CameraImageOrientation] = ...
    HORIZONTAL_MIRROR: ClassVar[CameraImageOrientation] = ...
    NORMAL: ClassVar[CameraImageOrientation] = ...
    ROTATE_180_DEG: ClassVar[CameraImageOrientation] = ...
    VERTICAL_FLIP: ClassVar[CameraImageOrientation] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class CameraInfo:
    cameraType: CameraModel
    distortionCoeff: List[float]
    extrinsics: Extrinsics
    height: int
    intrinsicMatrix: List[List[float]]
    specHfovDeg: float
    width: int
    def __init__(self) -> None: ...

class CameraModel:
    __members__: ClassVar[dict] = ...  # read-only
    Equirectangular: ClassVar[CameraModel] = ...
    Fisheye: ClassVar[CameraModel] = ...
    Perspective: ClassVar[CameraModel] = ...
    RadialDivision: ClassVar[CameraModel] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class CameraProperties:
    class ColorOrder:
        __members__: ClassVar[dict] = ...  # read-only
        BGR: ClassVar[CameraProperties.ColorOrder] = ...
        RGB: ClassVar[CameraProperties.ColorOrder] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class WarpMeshSource:
        __members__: ClassVar[dict] = ...  # read-only
        AUTO: ClassVar[CameraProperties.WarpMeshSource] = ...
        CALIBRATION: ClassVar[CameraProperties.WarpMeshSource] = ...
        NONE: ClassVar[CameraProperties.WarpMeshSource] = ...
        URI: ClassVar[CameraProperties.WarpMeshSource] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    boardSocket: CameraBoardSocket
    calibAlpha: Optional[float]
    cameraName: str
    colorOrder: CameraProperties.ColorOrder
    fp16: bool
    fps: float
    imageOrientation: CameraImageOrientation
    initialControl: CameraControl
    interleaved: bool
    isp3aFps: int
    ispScale: Any
    numFramesPoolIsp: int
    numFramesPoolPreview: int
    numFramesPoolRaw: int
    numFramesPoolStill: int
    numFramesPoolVideo: int
    previewHeight: int
    previewKeepAspectRatio: bool
    previewWidth: int
    rawPacked: Optional[bool]
    resolutionHeight: int
    resolutionWidth: int
    sensorCropX: float
    sensorCropY: float
    sensorType: CameraSensorType
    stillHeight: int
    stillWidth: int
    videoHeight: int
    videoWidth: int
    warpMeshHeight: int
    warpMeshSource: CameraProperties.WarpMeshSource
    warpMeshStepHeight: int
    warpMeshStepWidth: int
    warpMeshUri: str
    warpMeshWidth: int
    def __init__(self, *args, **kwargs) -> None: ...

class CameraSensorConfig:
    fov: Rect
    height: int
    maxFps: float
    minFps: float
    type: CameraSensorType
    width: int
    def __init__(self) -> None: ...

class CameraSensorType:
    __members__: ClassVar[dict] = ...  # read-only
    COLOR: ClassVar[CameraSensorType] = ...
    MONO: ClassVar[CameraSensorType] = ...
    THERMAL: ClassVar[CameraSensorType] = ...
    TOF: ClassVar[CameraSensorType] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class ChipTemperature:
    average: float
    css: float
    dss: float
    mss: float
    upa: float
    def __init__(self) -> None: ...

class ChipTemperatureS3:
    average: float
    css: float
    mss: float
    nce: float
    soc: float
    def __init__(self) -> None: ...

class Clock:
    def __init__(self, *args, **kwargs) -> None: ...
    def now(self) -> datetime.timedelta: ...

class ColorCameraProperties:
    class ColorOrder:
        __members__: ClassVar[dict] = ...  # read-only
        BGR: ClassVar[ColorCameraProperties.ColorOrder] = ...
        RGB: ClassVar[ColorCameraProperties.ColorOrder] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class SensorResolution:
        __members__: ClassVar[dict] = ...  # read-only
        THE_1080_P: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_1200_P: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_1280X962: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_12_MP: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_1352X1012: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_13_MP: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_1440X1080: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_2000X1500: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_2024X1520: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_2028X1520: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_2104X1560: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_240X180: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_4000X3000: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_48_MP: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_4_K: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_5312X6000: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_5_MP: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_720_P: ClassVar[ColorCameraProperties.SensorResolution] = ...
        THE_800_P: ClassVar[ColorCameraProperties.SensorResolution] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class WarpMeshSource:
        __members__: ClassVar[dict] = ...  # read-only
        AUTO: ClassVar[ColorCameraProperties.WarpMeshSource] = ...
        CALIBRATION: ClassVar[ColorCameraProperties.WarpMeshSource] = ...
        NONE: ClassVar[ColorCameraProperties.WarpMeshSource] = ...
        URI: ClassVar[ColorCameraProperties.WarpMeshSource] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    boardSocket: CameraBoardSocket
    calibAlpha: float
    eventFilter: List[FrameEvent]
    fps: float
    imageOrientation: CameraImageOrientation
    initialControl: CameraControl
    isp3aFps: int
    ispScale: Any
    numFramesPoolIsp: int
    numFramesPoolPreview: int
    numFramesPoolRaw: int
    numFramesPoolStill: int
    numFramesPoolVideo: int
    previewHeight: int
    previewKeepAspectRatio: bool
    previewWidth: int
    resolution: ColorCameraProperties.SensorResolution
    sensorCropX: float
    sensorCropY: float
    stillHeight: int
    stillWidth: int
    videoHeight: int
    videoWidth: int
    warpMeshHeight: int
    warpMeshSource: ColorCameraProperties.WarpMeshSource
    warpMeshStepHeight: int
    warpMeshStepWidth: int
    warpMeshUri: str
    warpMeshWidth: int
    def __init__(self, *args, **kwargs) -> None: ...

class Colormap:
    __members__: ClassVar[dict] = ...  # read-only
    JET: ClassVar[Colormap] = ...
    NONE: ClassVar[Colormap] = ...
    STEREO_JET: ClassVar[Colormap] = ...
    STEREO_TURBO: ClassVar[Colormap] = ...
    TURBO: ClassVar[Colormap] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class CpuUsage:
    average: float
    msTime: int
    def __init__(self) -> None: ...

class CrashDump:
    class CrashReport:
        class ErrorSourceInfo:
            class AssertContext:
                fileName: str
                functionName: str
                line: int
                def __init__(self) -> None: ...
        
            class TrapContext:
                trapAddress: int
                trapName: str
                trapNumber: int
                def __init__(self) -> None: ...
            assertContext: CrashDump.CrashReport.ErrorSourceInfo.AssertContext
            errorId: int
            trapContext: CrashDump.CrashReport.ErrorSourceInfo.TrapContext
            def __init__(self) -> None: ...
    
        class ThreadCallstack:
            class CallstackContext:
                callSite: int
                calledTarget: int
                context: str
                framePointer: int
                def __init__(self) -> None: ...
            callStack: List[CrashDump.CrashReport.ThreadCallstack.CallstackContext]
            instructionPointer: int
            stackBottom: int
            stackPointer: int
            stackTop: int
            threadId: int
            threadName: str
            threadStatus: str
            def __init__(self) -> None: ...
        crashedThreadId: int
        errorSource: str
        processor: ProcessorType
        threadCallstack: List[CrashDump.CrashReport.ThreadCallstack]
        def __init__(self) -> None: ...
    crashReports: List[CrashDump.CrashReport]
    depthaiCommitHash: str
    deviceId: str
    def __init__(self) -> None: ...
    def serializeToJson(self) -> json: ...

class DatatypeEnum:
    __members__: ClassVar[dict] = ...  # read-only
    AprilTagConfig: ClassVar[DatatypeEnum] = ...
    AprilTags: ClassVar[DatatypeEnum] = ...
    Buffer: ClassVar[DatatypeEnum] = ...
    CameraControl: ClassVar[DatatypeEnum] = ...
    EdgeDetectorConfig: ClassVar[DatatypeEnum] = ...
    EncodedFrame: ClassVar[DatatypeEnum] = ...
    FeatureTrackerConfig: ClassVar[DatatypeEnum] = ...
    IMUData: ClassVar[DatatypeEnum] = ...
    ImageManipConfig: ClassVar[DatatypeEnum] = ...
    ImgDetections: ClassVar[DatatypeEnum] = ...
    ImgFrame: ClassVar[DatatypeEnum] = ...
    NNData: ClassVar[DatatypeEnum] = ...
    PointCloudConfig: ClassVar[DatatypeEnum] = ...
    PointCloudData: ClassVar[DatatypeEnum] = ...
    SpatialImgDetections: ClassVar[DatatypeEnum] = ...
    SpatialLocationCalculatorConfig: ClassVar[DatatypeEnum] = ...
    SpatialLocationCalculatorData: ClassVar[DatatypeEnum] = ...
    StereoDepthConfig: ClassVar[DatatypeEnum] = ...
    SystemInformation: ClassVar[DatatypeEnum] = ...
    TrackedFeatures: ClassVar[DatatypeEnum] = ...
    Tracklets: ClassVar[DatatypeEnum] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class DetectionNetworkType:
    __members__: ClassVar[dict] = ...  # read-only
    MOBILENET: ClassVar[DetectionNetworkType] = ...
    YOLO: ClassVar[DetectionNetworkType] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class DetectionParserOptions:
    anchorMasks: Dict[str,List[int]]
    anchors: List[float]
    classes: int
    confidenceThreshold: float
    coordinates: int
    iouThreshold: float
    nnFamily: DetectionNetworkType
    def __init__(self, *args, **kwargs) -> None: ...

class DetectionParserProperties:
    parser: DetectionParserOptions
    def __init__(self, *args, **kwargs) -> None: ...

class Device(DeviceBase):
    class Config:
        board: BoardConfig
        logLevel: Optional[LogLevel]
        nonExclusiveMode: bool
        outputLogLevel: Optional[LogLevel]
        version: OpenVINO.Version
        def __init__(self) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline, usb2Mode: bool) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline, maxUsbSpeed: UsbSpeed) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline, pathToCmd: Path) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline, devInfo: DeviceInfo, usb2Mode: bool = ...) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline, deviceInfo: DeviceInfo, maxUsbSpeed: UsbSpeed) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline, devInfo: DeviceInfo, pathToCmd: Path) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version = ...) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version, usb2Mode: bool = ...) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version, maxUsbSpeed: UsbSpeed) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version, pathToCmd: Path) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version, deviceInfo: DeviceInfo, usb2Mode: bool = ...) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version, deviceInfo: DeviceInfo, maxUsbSpeed: UsbSpeed) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version, deviceDesc: DeviceInfo, pathToCmd: Path) -> None: ...
    @overload
    def __init__(self, config: Device.Config) -> None: ...
    @overload
    def __init__(self, config: Device.Config, deviceInfo: DeviceInfo) -> None: ...
    @overload
    def __init__(self, deviceInfo: DeviceInfo) -> None: ...
    @overload
    def __init__(self, deviceInfo: DeviceInfo, maxUsbSpeed: UsbSpeed) -> None: ...
    @overload
    def __init__(self, nameOrDeviceId: str) -> None: ...
    @overload
    def __init__(self, nameOrDeviceId: str, maxUsbSpeed: UsbSpeed) -> None: ...

class DeviceBase:
    @overload
    def __init__(self, pipeline: Pipeline) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline, usb2Mode: bool) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline, maxUsbSpeed: UsbSpeed) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline, pathToCmd: Path) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline, devInfo: DeviceInfo, usb2Mode: bool = ...) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline, deviceInfo: DeviceInfo, maxUsbSpeed: UsbSpeed) -> None: ...
    @overload
    def __init__(self, pipeline: Pipeline, devInfo: DeviceInfo, pathToCmd: Path) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version = ...) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version, usb2Mode: bool = ...) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version, maxUsbSpeed: UsbSpeed) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version, pathToCmd: Path) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version, deviceInfo: DeviceInfo, usb2Mode: bool = ...) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version, deviceInfo: DeviceInfo, maxUsbSpeed: UsbSpeed) -> None: ...
    @overload
    def __init__(self, version: OpenVINO.Version, deviceDesc: DeviceInfo, pathToCmd: Path) -> None: ...
    @overload
    def __init__(self, config: Device.Config) -> None: ...
    @overload
    def __init__(self, config: Device.Config, deviceInfo: DeviceInfo) -> None: ...
    @overload
    def __init__(self, deviceInfo: DeviceInfo) -> None: ...
    @overload
    def __init__(self, deviceInfo: DeviceInfo, maxUsbSpeed: UsbSpeed) -> None: ...
    @overload
    def __init__(self, nameOrDeviceId: str) -> None: ...
    @overload
    def __init__(self, nameOrDeviceId: str, maxUsbSpeed: UsbSpeed) -> None: ...
    def addLogCallback(self, callback: Callable[[LogMessage],None]) -> int: ...
    def close(self) -> None: ...
    def factoryResetCalibration(self) -> None: ...
    def flashCalibration(self, calibrationDataHandler: CalibrationHandler) -> bool: ...
    def flashCalibration2(self, arg0: CalibrationHandler) -> None: ...
    def flashEepromClear(self) -> None: ...
    def flashFactoryCalibration(self, arg0: CalibrationHandler) -> None: ...
    def flashFactoryEepromClear(self) -> None: ...
    @classmethod
    def getAllAvailableDevices(cls) -> List[DeviceInfo]: ...
    @classmethod
    def getAllConnectedDevices(cls) -> List[DeviceInfo]: ...
    @overload
    @classmethod
    def getAnyAvailableDevice(cls, timeout: datetime.timedelta) -> Tuple[bool,DeviceInfo]: ...
    @overload
    @classmethod
    def getAnyAvailableDevice(cls) -> Tuple[bool,DeviceInfo]: ...
    def getAvailableStereoPairs(self) -> List[StereoPair]: ...
    def getBootloaderVersion(self) -> Optional[Version]: ...
    def getCameraSensorNames(self) -> Dict[CameraBoardSocket,str]: ...
    def getChipTemperature(self) -> ChipTemperature: ...
    def getCmxMemoryUsage(self) -> MemoryInfo: ...
    def getConnectedCameraFeatures(self) -> List[CameraFeatures]: ...
    def getConnectedCameras(self) -> List[CameraBoardSocket]: ...
    def getConnectedIMU(self) -> str: ...
    def getConnectionInterfaces(self) -> List[connectionInterface]: ...
    def getCrashDump(self, clearCrashDump: bool = ...) -> CrashDump: ...
    def getDdrMemoryUsage(self) -> MemoryInfo: ...
    @classmethod
    def getDeviceByMxId(cls, mxId: str) -> Tuple[bool,DeviceInfo]: ...
    def getDeviceInfo(self) -> DeviceInfo: ...
    def getDeviceName(self) -> object: ...
    @overload
    @classmethod
    def getEmbeddedDeviceBinary(cls, usb2Mode: bool, version: OpenVINO.Version = ...) -> List[int]: ...
    @overload
    @classmethod
    def getEmbeddedDeviceBinary(cls, config: Device.Config) -> List[int]: ...
    def getEmbeddedIMUFirmwareVersion(self) -> Version: ...
    @classmethod
    def getFirstAvailableDevice(cls, skipInvalidDevices: bool = ...) -> Tuple[bool,DeviceInfo]: ...
    @classmethod
    def getGlobalProfilingData(cls) -> ProfilingData: ...
    def getIMUFirmwareUpdateStatus(self) -> Tuple[bool,float]: ...
    def getIMUFirmwareVersion(self) -> Version: ...
    def getIrDrivers(self) -> List[Tuple[str,int,int]]: ...
    def getLeonCssCpuUsage(self) -> CpuUsage: ...
    def getLeonCssHeapUsage(self) -> MemoryInfo: ...
    def getLeonMssCpuUsage(self) -> CpuUsage: ...
    def getLeonMssHeapUsage(self) -> MemoryInfo: ...
    def getLogLevel(self) -> LogLevel: ...
    def getLogOutputLevel(self) -> LogLevel: ...
    def getMxId(self) -> str: ...
    def getProductName(self) -> object: ...
    def getProfilingData(self) -> ProfilingData: ...
    def getStereoPairs(self) -> List[StereoPair]: ...
    def getSystemInformationLoggingRate(self) -> float: ...
    def getUsbSpeed(self) -> UsbSpeed: ...
    def getXLinkChunkSize(self) -> int: ...
    def hasCrashDump(self) -> bool: ...
    def isClosed(self) -> bool: ...
    def isEepromAvailable(self) -> bool: ...
    def isPipelineRunning(self) -> bool: ...
    def readCalibration(self) -> CalibrationHandler: ...
    def readCalibration2(self) -> CalibrationHandler: ...
    def readCalibrationOrDefault(self) -> CalibrationHandler: ...
    def readCalibrationRaw(self) -> List[int]: ...
    def readFactoryCalibration(self) -> CalibrationHandler: ...
    def readFactoryCalibrationOrDefault(self) -> CalibrationHandler: ...
    def readFactoryCalibrationRaw(self) -> List[int]: ...
    def removeLogCallback(self, callbackId: int) -> bool: ...
    def setIrFloodLightBrightness(self, mA: float, mask: int = ...) -> bool: ...
    def setIrFloodLightIntensity(self, intensity: float, mask: int = ...) -> bool: ...
    def setIrLaserDotProjectorBrightness(self, mA: float, mask: int = ...) -> bool: ...
    def setIrLaserDotProjectorIntensity(self, intensity: float, mask: int = ...) -> bool: ...
    def setLogLevel(self, level: LogLevel) -> None: ...
    def setLogOutputLevel(self, level: LogLevel) -> None: ...
    def setSystemInformationLoggingRate(self, rateHz: float) -> None: ...
    @overload
    def setTimesync(self, arg0: datetime.timedelta, arg1: int, arg2: bool) -> None: ...
    @overload
    def setTimesync(self, enable: bool) -> None: ...
    def setXLinkChunkSize(self, sizeBytes: int) -> None: ...
    def startIMUFirmwareUpdate(self, forceUpdate: bool = ...) -> bool: ...
    @overload
    def startPipeline(self) -> None: ...
    @overload
    def startPipeline(self, arg0: Pipeline) -> bool: ...
    def __enter__(self) -> DeviceBase: ...
    def __exit__(self, arg0: object, arg1: object, arg2: object) -> None: ...

class DeviceBootloader:
    class ApplicationInfo:
        applicationName: str
        firmwareVersion: str
        hasApplication: bool
        def __init__(self) -> None: ...

    class Config:
        appMem: DeviceBootloader.Memory
        network: DeviceBootloader.NetworkConfig
        usb: DeviceBootloader.UsbConfig
        def __init__(self) -> None: ...
        def fromJson(self) -> DeviceBootloader.Config: ...
        def getDnsAltIPv4(self) -> str: ...
        def getDnsIPv4(self) -> str: ...
        def getIPv4(self) -> str: ...
        def getIPv4Gateway(self) -> str: ...
        def getIPv4Mask(self) -> str: ...
        def getMacAddress(self) -> str: ...
        def getNetworkTimeout(self) -> datetime.timedelta: ...
        def getUsbMaxSpeed(self) -> UsbSpeed: ...
        def getUsbTimeout(self) -> datetime.timedelta: ...
        def isStaticIPV4(self) -> bool: ...
        def setDnsIPv4(self, arg0: str, arg1: str) -> None: ...
        def setDynamicIPv4(self, arg0: str, arg1: str, arg2: str) -> None: ...
        def setMacAddress(self, arg0: str) -> None: ...
        def setNetworkTimeout(self, arg0: datetime.timedelta) -> None: ...
        def setStaticIPv4(self, arg0: str, arg1: str, arg2: str) -> None: ...
        def setUsbMaxSpeed(self, arg0: UsbSpeed) -> None: ...
        def setUsbTimeout(self, arg0: datetime.timedelta) -> None: ...
        def toJson(self) -> json: ...

    class Memory:
        __members__: ClassVar[dict] = ...  # read-only
        AUTO: ClassVar[DeviceBootloader.Memory] = ...
        EMMC: ClassVar[DeviceBootloader.Memory] = ...
        FLASH: ClassVar[DeviceBootloader.Memory] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class MemoryInfo:
        available: bool
        info: str
        size: int
        def __init__(self) -> None: ...

    class NetworkConfig:
        ipv4: int
        ipv4Dns: int
        ipv4DnsAlt: int
        ipv4Gateway: int
        ipv4Mask: int
        ipv6: List[int[4]]
        ipv6Dns: List[int[4]]
        ipv6DnsAlt: List[int[4]]
        ipv6Gateway: List[int[4]]
        ipv6Prefix: int
        mac: List[int[6]]
        staticIpv4: bool
        staticIpv6: bool
        timeoutMs: int
        def __init__(self) -> None: ...

    class Section:
        __members__: ClassVar[dict] = ...  # read-only
        APPLICATION: ClassVar[DeviceBootloader.Section] = ...
        AUTO: ClassVar[DeviceBootloader.Section] = ...
        BOOTLOADER: ClassVar[DeviceBootloader.Section] = ...
        BOOTLOADER_CONFIG: ClassVar[DeviceBootloader.Section] = ...
        HEADER: ClassVar[DeviceBootloader.Section] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class Type:
        __members__: ClassVar[dict] = ...  # read-only
        AUTO: ClassVar[DeviceBootloader.Type] = ...
        NETWORK: ClassVar[DeviceBootloader.Type] = ...
        USB: ClassVar[DeviceBootloader.Type] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class UsbConfig:
        maxUsbSpeed: int
        pid: int
        timeoutMs: int
        vid: int
        def __init__(self) -> None: ...
    @overload
    def __init__(self, devInfo: DeviceInfo, allowFlashingBootloader: bool = ...) -> None: ...
    @overload
    def __init__(self, devInfo: DeviceInfo, pathToCmd: Path, allowFlashingBootloader: bool = ...) -> None: ...
    @overload
    def __init__(self, nameOrDeviceId: str, allowFlashingBootloader: bool = ...) -> None: ...
    def bootMemory(self, fw: List[int]) -> None: ...
    def bootUsbRomBootloader(self) -> None: ...
    def close(self) -> None: ...
    @overload
    @classmethod
    def createDepthaiApplicationPackage(cls, pipeline: Pipeline, pathToCmd: Path = ..., compress: bool = ..., applicationName: str = ..., checkChecksum: bool = ...) -> List[int]: ...
    @overload
    @classmethod
    def createDepthaiApplicationPackage(cls, pipeline: Pipeline, compress: bool, applicationName: str = ..., checkChecksum: bool = ...) -> List[int]: ...
    @overload
    def flash(self, progressCallback: Callable[[float],None], pipeline: Pipeline, compress: bool = ..., applicationName: str = ..., memory: DeviceBootloader.Memory = ..., checkChecksum: bool = ...) -> Tuple[bool,str]: ...
    @overload
    def flash(self, pipeline: Pipeline, compress: bool = ..., applicationName: str = ..., memory: DeviceBootloader.Memory = ..., checkChecksum: bool = ...) -> Tuple[bool,str]: ...
    def flashBootHeader(self, memory: DeviceBootloader.Memory, frequency: int = ..., location: int = ..., dummyCycles: int = ..., offset: int = ...) -> Tuple[bool,str]: ...
    @overload
    def flashBootloader(self, progressCallback: Callable[[float],None], path: Path = ...) -> Tuple[bool,str]: ...
    @overload
    def flashBootloader(self, memory: DeviceBootloader.Memory, type: DeviceBootloader.Type, progressCallback: Callable[[float],None], path: Path = ...) -> Tuple[bool,str]: ...
    def flashClear(self, memory: DeviceBootloader.Memory = ...) -> Tuple[bool,str]: ...
    def flashConfig(self, config: DeviceBootloader.Config, memory: DeviceBootloader.Memory = ..., type: DeviceBootloader.Type = ...) -> Tuple[bool,str]: ...
    def flashConfigClear(self, memory: DeviceBootloader.Memory = ..., type: DeviceBootloader.Type = ...) -> Tuple[bool,str]: ...
    def flashConfigData(self, configData: json, memory: DeviceBootloader.Memory = ..., type: DeviceBootloader.Type = ...) -> Tuple[bool,str]: ...
    def flashConfigFile(self, configData: Path, memory: DeviceBootloader.Memory = ..., type: DeviceBootloader.Type = ...) -> Tuple[bool,str]: ...
    @overload
    def flashCustom(self, memory: DeviceBootloader.Memory, offset: int, data: List[int], progressCallback: Callable[[float],None] = ...) -> Tuple[bool,str]: ...
    @overload
    def flashCustom(self, memory: DeviceBootloader.Memory, offset: int, filename: str, progressCallback: Callable[[float],None] = ...) -> Tuple[bool,str]: ...
    @overload
    def flashDepthaiApplicationPackage(self, progressCallback: Callable[[float],None], package: List[int], memory: DeviceBootloader.Memory = ...) -> Tuple[bool,str]: ...
    @overload
    def flashDepthaiApplicationPackage(self, package: List[int], memory: DeviceBootloader.Memory = ...) -> Tuple[bool,str]: ...
    def flashFastBootHeader(self, memory: DeviceBootloader.Memory, frequency: int = ..., location: int = ..., dummyCycles: int = ..., offset: int = ...) -> Tuple[bool,str]: ...
    def flashGpioModeBootHeader(self, memory: DeviceBootloader.Memory, mode: int) -> Tuple[bool,str]: ...
    def flashUsbRecoveryBootHeader(self, memory: DeviceBootloader.Memory) -> Tuple[bool,str]: ...
    def flashUserBootloader(self, progressCallback: Callable[[float],None], path: Path = ...) -> Tuple[bool,str]: ...
    @classmethod
    def getAllAvailableDevices(cls) -> List[DeviceInfo]: ...
    @classmethod
    def getEmbeddedBootloaderBinary(cls, arg0: DeviceBootloader.Type) -> List[int]: ...
    @classmethod
    def getEmbeddedBootloaderVersion(cls) -> Version: ...
    @classmethod
    def getFirstAvailableDevice(cls) -> Tuple[bool,DeviceInfo]: ...
    def getMemoryInfo(self, arg0: DeviceBootloader.Memory) -> DeviceBootloader.MemoryInfo: ...
    def getType(self) -> DeviceBootloader.Type: ...
    def getVersion(self) -> Version: ...
    def isAllowedFlashingBootloader(self) -> bool: ...
    def isEmbeddedVersion(self) -> bool: ...
    def isUserBootloader(self) -> bool: ...
    def isUserBootloaderSupported(self) -> bool: ...
    def readApplicationInfo(self, memory: DeviceBootloader.Memory) -> DeviceBootloader.ApplicationInfo: ...
    def readConfig(self, memory: DeviceBootloader.Memory = ..., type: DeviceBootloader.Type = ...) -> DeviceBootloader.Config: ...
    def readConfigData(self, memory: DeviceBootloader.Memory = ..., type: DeviceBootloader.Type = ...) -> json: ...
    @overload
    def readCustom(self, memory: DeviceBootloader.Memory, offset: int, size: int, filename: str, progressCallback: Callable[[float],None] = ...) -> Tuple[bool,str]: ...
    @overload
    def readCustom(self, memory: DeviceBootloader.Memory, offset: int, size: int, progressCallback: Callable[[float],None] = ...) -> Tuple[bool,str,List[int]]: ...
    @overload
    @classmethod
    def saveDepthaiApplicationPackage(cls, path: Path, pipeline: Pipeline, pathToCmd: Path = ..., compress: bool = ..., applicationName: str = ..., checkChecksum: bool = ...) -> None: ...
    @overload
    @classmethod
    def saveDepthaiApplicationPackage(cls, path: Path, pipeline: Pipeline, compress: bool, applicationName: str = ..., checkChecksum: bool = ...) -> None: ...
    def __enter__(self) -> DeviceBootloader: ...
    def __exit__(self, arg0: object, arg1: object, arg2: object) -> None: ...

class DeviceDesc:
    mxid: str
    name: str
    platform: XLinkPlatform
    protocol: XLinkProtocol
    state: XLinkDeviceState
    status: XLinkError_t
    def __init__(self) -> None: ...

class DeviceInfo:
    desc: object
    mxid: str
    name: str
    platform: XLinkPlatform
    protocol: XLinkProtocol
    state: XLinkDeviceState
    status: XLinkError_t
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str, mxid: str, state: XLinkDeviceState, protocol: XLinkProtocol, platform: XLinkPlatform, status: XLinkError_t) -> None: ...
    @overload
    def __init__(self, mxidOrName: str) -> None: ...
    @overload
    def __init__(self, arg0: DeviceDesc) -> None: ...
    def getMxId(self) -> str: ...
    def getXLinkDeviceDesc(self) -> DeviceDesc: ...

class DeviceNode(ThreadedNode):
    def __init__(self, *args, **kwargs) -> None: ...

class EdgeDetectorConfig(Buffer):
    def __init__(self) -> None: ...
    def getConfigData(self) -> EdgeDetectorConfigData: ...
    def setSobelFilterKernels(self, horizontalKernel: List[List[int]], verticalKernel: List[List[int]]) -> None: ...

class EdgeDetectorConfigData:
    sobelFilterHorizontalKernel: List[List[int]]
    sobelFilterVerticalKernel: List[List[int]]
    def __init__(self) -> None: ...

class EdgeDetectorProperties:
    initialConfig: EdgeDetectorConfig
    numFramesPool: int
    outputFrameSize: int
    def __init__(self, *args, **kwargs) -> None: ...

class EepromData:
    batchName: str
    batchTime: int
    boardConf: str
    boardCustom: str
    boardName: str
    boardOptions: int
    boardRev: str
    cameraData: Dict[CameraBoardSocket,CameraInfo]
    deviceName: str
    hardwareConf: str
    housingExtrinsics: Extrinsics
    imuExtrinsics: Extrinsics
    miscellaneousData: List[int]
    productName: str
    stereoEnableDistortionCorrection: bool
    stereoRectificationData: StereoRectification
    stereoUseSpecTranslation: bool
    version: int
    verticalCameraSocket: CameraBoardSocket
    def __init__(self) -> None: ...

class EepromError(RuntimeError): ...

class EncodedFrame(Buffer):
    class FrameType:
        __members__: ClassVar[dict] = ...  # read-only
        B: ClassVar[EncodedFrame.FrameType] = ...
        I: ClassVar[EncodedFrame.FrameType] = ...
        P: ClassVar[EncodedFrame.FrameType] = ...
        Unknown: ClassVar[EncodedFrame.FrameType] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class Profile:
        __members__: ClassVar[dict] = ...  # read-only
        AVC: ClassVar[EncodedFrame.Profile] = ...
        HEVC: ClassVar[EncodedFrame.Profile] = ...
        JPEG: ClassVar[EncodedFrame.Profile] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    def __init__(self) -> None: ...
    def getBitrate(self) -> int: ...
    def getColorTemperature(self) -> int: ...
    def getExposureTime(self) -> datetime.timedelta: ...
    def getFrameType(self) -> EncodedFrame.FrameType: ...
    def getHeight(self) -> int: ...
    def getInstanceNum(self) -> int: ...
    def getLensPosition(self) -> int: ...
    def getLensPositionRaw(self) -> float: ...
    def getLossless(self) -> bool: ...
    def getProfile(self) -> EncodedFrame.Profile: ...
    def getQuality(self) -> int: ...
    def getSensitivity(self) -> int: ...
    def getSequenceNum(self) -> int: ...
    def getTimestamp(self) -> datetime.timedelta: ...
    def getTimestampDevice(self) -> datetime.timedelta: ...
    def getWidth(self) -> int: ...
    def setBitrate(self, arg0: int) -> EncodedFrame: ...
    def setFrameType(self, arg0: EncodedFrame.FrameType) -> EncodedFrame: ...
    def setHeight(self, height: int) -> EncodedFrame: ...
    def setLossless(self, arg0: bool) -> EncodedFrame: ...
    def setProfile(self, arg0: EncodedFrame.Profile) -> EncodedFrame: ...
    def setQuality(self, arg0: int) -> EncodedFrame: ...
    @overload
    def setSize(self, width: int, height: int) -> EncodedFrame: ...
    @overload
    def setSize(self, sizer: Tuple[int,int]) -> EncodedFrame: ...
    def setWidth(self, width: int) -> EncodedFrame: ...

class Extrinsics:
    rotationMatrix: List[List[float]]
    specTranslation: Point3f
    toCameraSocket: CameraBoardSocket
    translation: Point3f
    def __init__(self) -> None: ...

class FeatureTrackerConfig(Buffer):
    class CornerDetector:
        class Thresholds:
            decreaseFactor: float
            increaseFactor: float
            initialValue: float
            max: float
            min: float
            def __init__(self) -> None: ...
    
        class Type:
            __members__: ClassVar[dict] = ...  # read-only
            HARRIS: ClassVar[FeatureTrackerConfig.CornerDetector.Type] = ...
            SHI_THOMASI: ClassVar[FeatureTrackerConfig.CornerDetector.Type] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        cellGridDimension: int
        enableSobel: bool
        enableSorting: bool
        numMaxFeatures: int
        numTargetFeatures: int
        thresholds: FeatureTrackerConfig.CornerDetector.Thresholds
        type: FeatureTrackerConfig.CornerDetector.Type
        def __init__(self) -> None: ...

    class FeatureMaintainer:
        enable: bool
        lostFeatureErrorThreshold: float
        minimumDistanceBetweenFeatures: float
        trackedFeatureThreshold: float
        def __init__(self) -> None: ...

    class MotionEstimator:
        class OpticalFlow:
            epsilon: float
            maxIterations: int
            pyramidLevels: int
            searchWindowHeight: int
            searchWindowWidth: int
            def __init__(self) -> None: ...
    
        class Type:
            __members__: ClassVar[dict] = ...  # read-only
            HW_MOTION_ESTIMATION: ClassVar[FeatureTrackerConfig.MotionEstimator.Type] = ...
            LUCAS_KANADE_OPTICAL_FLOW: ClassVar[FeatureTrackerConfig.MotionEstimator.Type] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        enable: bool
        opticalFlow: FeatureTrackerConfig.MotionEstimator.OpticalFlow
        type: FeatureTrackerConfig.MotionEstimator.Type
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...
    @overload
    def setCornerDetector(self, cornerDetector: FeatureTrackerConfig.CornerDetector.Type) -> FeatureTrackerConfig: ...
    @overload
    def setCornerDetector(self, config: FeatureTrackerConfig.CornerDetector) -> FeatureTrackerConfig: ...
    @overload
    def setFeatureMaintainer(self, enable: bool) -> FeatureTrackerConfig: ...
    @overload
    def setFeatureMaintainer(self, config: FeatureTrackerConfig.FeatureMaintainer) -> FeatureTrackerConfig: ...
    def setHwMotionEstimation(self) -> FeatureTrackerConfig: ...
    @overload
    def setMotionEstimator(self, enable: bool) -> FeatureTrackerConfig: ...
    @overload
    def setMotionEstimator(self, config: FeatureTrackerConfig.MotionEstimator) -> FeatureTrackerConfig: ...
    def setNumTargetFeatures(self, numTargetFeatures: int) -> FeatureTrackerConfig: ...
    @overload
    def setOpticalFlow(self) -> FeatureTrackerConfig: ...
    @overload
    def setOpticalFlow(self, config: FeatureTrackerConfig.MotionEstimator.OpticalFlow) -> FeatureTrackerConfig: ...

class FeatureTrackerProperties:
    initialConfig: FeatureTrackerConfig
    numMemorySlices: int
    numShaves: int
    def __init__(self, *args, **kwargs) -> None: ...

class FrameEvent:
    __members__: ClassVar[dict] = ...  # read-only
    NONE: ClassVar[FrameEvent] = ...
    READOUT_END: ClassVar[FrameEvent] = ...
    READOUT_START: ClassVar[FrameEvent] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class GlobalProperties:
    cameraTuningBlobSize: Optional[int]
    cameraTuningBlobUri: str
    leonOsFrequencyHz: float
    leonRtFrequencyHz: float
    pipelineName: Optional[str]
    pipelineVersion: Optional[str]
    sippBufferSize: int
    sippDmaBufferSize: int
    xlinkChunkSize: int
    def __init__(self, *args, **kwargs) -> None: ...

class IMUData(Buffer):
    packets: List[IMUPacket]
    def __init__(self) -> None: ...

class IMUPacket:
    acceleroMeter: IMUReportAccelerometer
    gyroscope: IMUReportGyroscope
    magneticField: IMUReportMagneticField
    rotationVector: IMUReportRotationVectorWAcc
    def __init__(self) -> None: ...

class IMUProperties:
    batchReportThreshold: int
    enableFirmwareUpdate: Optional[bool]
    imuSensors: List[IMUSensorConfig]
    maxBatchReports: int
    def __init__(self, *args, **kwargs) -> None: ...

class IMUReport:
    class Accuracy:
        __members__: ClassVar[dict] = ...  # read-only
        HIGH: ClassVar[IMUReport.Accuracy] = ...
        LOW: ClassVar[IMUReport.Accuracy] = ...
        MEDIUM: ClassVar[IMUReport.Accuracy] = ...
        UNRELIABLE: ClassVar[IMUReport.Accuracy] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    accuracy: IMUReport.Accuracy
    sequence: int
    timestamp: Timestamp
    tsDevice: Timestamp
    def __init__(self) -> None: ...
    def getSequenceNum(self) -> int: ...
    def getTimestamp(self) -> datetime.timedelta: ...
    def getTimestampDevice(self) -> datetime.timedelta: ...

class IMUReportAccelerometer(IMUReport):
    x: float
    y: float
    z: float
    def __init__(self) -> None: ...

class IMUReportGyroscope(IMUReport):
    x: float
    y: float
    z: float
    def __init__(self) -> None: ...

class IMUReportMagneticField(IMUReport):
    x: float
    y: float
    z: float
    def __init__(self) -> None: ...

class IMUReportRotationVectorWAcc(IMUReport):
    i: float
    j: float
    k: float
    real: float
    rotationVectorAccuracy: float
    def __init__(self) -> None: ...

class IMUSensor:
    __members__: ClassVar[dict] = ...  # read-only
    ACCELEROMETER: ClassVar[IMUSensor] = ...
    ACCELEROMETER_RAW: ClassVar[IMUSensor] = ...
    ARVR_STABILIZED_GAME_ROTATION_VECTOR: ClassVar[IMUSensor] = ...
    ARVR_STABILIZED_ROTATION_VECTOR: ClassVar[IMUSensor] = ...
    GAME_ROTATION_VECTOR: ClassVar[IMUSensor] = ...
    GEOMAGNETIC_ROTATION_VECTOR: ClassVar[IMUSensor] = ...
    GRAVITY: ClassVar[IMUSensor] = ...
    GYROSCOPE_CALIBRATED: ClassVar[IMUSensor] = ...
    GYROSCOPE_RAW: ClassVar[IMUSensor] = ...
    GYROSCOPE_UNCALIBRATED: ClassVar[IMUSensor] = ...
    LINEAR_ACCELERATION: ClassVar[IMUSensor] = ...
    MAGNETOMETER_CALIBRATED: ClassVar[IMUSensor] = ...
    MAGNETOMETER_RAW: ClassVar[IMUSensor] = ...
    MAGNETOMETER_UNCALIBRATED: ClassVar[IMUSensor] = ...
    ROTATION_VECTOR: ClassVar[IMUSensor] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class IMUSensorConfig:
    changeSensitivity: int
    reportRate: int
    sensitivityEnabled: bool
    sensitivityRelative: bool
    sensorId: IMUSensor
    def __init__(self) -> None: ...

class ImageManipConfig(Buffer):
    class CropConfig:
        cropRatio: float
        cropRect: ImageManipConfig.CropRect
        cropRotatedRect: RotatedRect
        enableCenterCropRectangle: bool
        enableRotatedRect: bool
        normalizedCoords: bool
        widthHeightAspectRatio: float
        def __init__(self) -> None: ...

    class CropRect:
        xmax: float
        xmin: float
        ymax: float
        ymin: float
        def __init__(self) -> None: ...

    class FormatConfig:
        flipHorizontal: bool
        flipVertical: bool
        type: ImgFrame.Type
        def __init__(self) -> None: ...

    class ResizeConfig:
        bgBlue: str
        bgGreen: str
        bgRed: str
        enableRotation: bool
        enableWarp4pt: bool
        enableWarpMatrix: bool
        height: int
        keepAspectRatio: bool
        lockAspectRatioFill: bool
        normalizedCoords: bool
        rotationAngleDeg: float
        warpBorderReplicate: bool
        warpFourPoints: List[Point2f]
        warpMatrix3x3: List[float]
        width: int
        def __init__(self) -> None: ...
    cropConfig: ImageManipConfig.CropConfig
    enableCrop: bool
    enableFormat: bool
    enableResize: bool
    formatConfig: ImageManipConfig.FormatConfig
    interpolation: Interpolation
    resizeConfig: ImageManipConfig.ResizeConfig
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def getColormap(self) -> Colormap: ...
    def getCropConfig(self) -> ImageManipConfig.CropConfig: ...
    def getCropXMax(self) -> float: ...
    def getCropXMin(self) -> float: ...
    def getCropYMax(self) -> float: ...
    def getCropYMin(self) -> float: ...
    def getFormatConfig(self) -> ImageManipConfig.FormatConfig: ...
    def getInterpolation(self) -> Interpolation: ...
    def getResizeConfig(self) -> ImageManipConfig.ResizeConfig: ...
    def getResizeHeight(self) -> int: ...
    def getResizeWidth(self) -> int: ...
    def isResizeThumbnail(self) -> bool: ...
    def setCenterCrop(self, ratio: float, whRatio: float = ...) -> ImageManipConfig: ...
    @overload
    def setColormap(self, colormap: Colormap, min: int, max: int) -> ImageManipConfig: ...
    @overload
    def setColormap(self, colormap: Colormap, max: int = ...) -> ImageManipConfig: ...
    @overload
    def setColormap(self, colormap: Colormap, max: float = ...) -> ImageManipConfig: ...
    @overload
    def setCropRect(self, xmin: float, ymin: float, xmax: float, ymax: float) -> ImageManipConfig: ...
    @overload
    def setCropRect(self, coordinates: Tuple[float,float,float,float]) -> ImageManipConfig: ...
    def setCropRotatedRect(self, rr: RotatedRect, normalizedCoords: bool = ...) -> ImageManipConfig: ...
    def setFrameType(self, type: ImgFrame.Type) -> ImageManipConfig: ...
    def setHorizontalFlip(self, flip: bool) -> ImageManipConfig: ...
    def setInterpolation(self, interpolation: Interpolation) -> ImageManipConfig: ...
    def setKeepAspectRatio(self, keep: bool) -> ImageManipConfig: ...
    @overload
    def setResize(self, w: int, h: int) -> ImageManipConfig: ...
    @overload
    def setResize(self, size: Tuple[int,int]) -> ImageManipConfig: ...
    @overload
    def setResizeThumbnail(self, w: int, h: int, bgRed: int = ..., bgGreen: int = ..., bgBlue: int = ...) -> ImageManipConfig: ...
    @overload
    def setResizeThumbnail(self, size: Tuple[int,int], bgRed: int = ..., bgGreen: int = ..., bgBlue: int = ...) -> ImageManipConfig: ...
    def setReusePreviousImage(self, reuse: bool) -> ImageManipConfig: ...
    def setRotationDegrees(self, deg: float) -> ImageManipConfig: ...
    def setRotationRadians(self, rad: float) -> ImageManipConfig: ...
    def setSkipCurrentImage(self, skip: bool) -> ImageManipConfig: ...
    def setVerticalFlip(self, flip: bool) -> None: ...
    def setWarpBorderFillColor(self, red: int, green: int, blue: int) -> ImageManipConfig: ...
    def setWarpBorderReplicatePixels(self) -> ImageManipConfig: ...
    def setWarpTransformFourPoints(self, pt: List[Point2f], normalizedCoords: bool) -> ImageManipConfig: ...
    def setWarpTransformMatrix3x3(self, mat: List[float]) -> ImageManipConfig: ...

class ImgDetection:
    confidence: float
    label: int
    xmax: float
    xmin: float
    ymax: float
    ymin: float
    def __init__(self) -> None: ...

class ImgDetections(Buffer):
    detections: List[ImgDetection]
    def __init__(self) -> None: ...
    def getSequenceNum(self) -> int: ...
    def getTimestamp(self) -> datetime.timedelta: ...
    def getTimestampDevice(self) -> datetime.timedelta: ...

class ImgFrame(Buffer):
    class Specs:
        bytesPP: int
        height: int
        p1Offset: int
        p2Offset: int
        p3Offset: int
        stride: int
        type: ImgFrame.Type
        width: int
        def __init__(self) -> None: ...

    class Type:
        __members__: ClassVar[dict] = ...  # read-only
        BGR888i: ClassVar[ImgFrame.Type] = ...
        BGR888p: ClassVar[ImgFrame.Type] = ...
        BGRF16F16F16i: ClassVar[ImgFrame.Type] = ...
        BGRF16F16F16p: ClassVar[ImgFrame.Type] = ...
        BITSTREAM: ClassVar[ImgFrame.Type] = ...
        GRAY8: ClassVar[ImgFrame.Type] = ...
        GRAYF16: ClassVar[ImgFrame.Type] = ...
        HDR: ClassVar[ImgFrame.Type] = ...
        LUT16: ClassVar[ImgFrame.Type] = ...
        LUT2: ClassVar[ImgFrame.Type] = ...
        LUT4: ClassVar[ImgFrame.Type] = ...
        NONE: ClassVar[ImgFrame.Type] = ...
        NV12: ClassVar[ImgFrame.Type] = ...
        NV21: ClassVar[ImgFrame.Type] = ...
        PACK10: ClassVar[ImgFrame.Type] = ...
        PACK12: ClassVar[ImgFrame.Type] = ...
        RAW10: ClassVar[ImgFrame.Type] = ...
        RAW12: ClassVar[ImgFrame.Type] = ...
        RAW14: ClassVar[ImgFrame.Type] = ...
        RAW16: ClassVar[ImgFrame.Type] = ...
        RAW32: ClassVar[ImgFrame.Type] = ...
        RAW8: ClassVar[ImgFrame.Type] = ...
        RGB161616: ClassVar[ImgFrame.Type] = ...
        RGB888i: ClassVar[ImgFrame.Type] = ...
        RGB888p: ClassVar[ImgFrame.Type] = ...
        RGBA8888: ClassVar[ImgFrame.Type] = ...
        RGBF16F16F16i: ClassVar[ImgFrame.Type] = ...
        RGBF16F16F16p: ClassVar[ImgFrame.Type] = ...
        YUV400p: ClassVar[ImgFrame.Type] = ...
        YUV420p: ClassVar[ImgFrame.Type] = ...
        YUV422i: ClassVar[ImgFrame.Type] = ...
        YUV422p: ClassVar[ImgFrame.Type] = ...
        YUV444i: ClassVar[ImgFrame.Type] = ...
        YUV444p: ClassVar[ImgFrame.Type] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: int) -> None: ...
    def getBytesPerPixel(self) -> float: ...
    def getCategory(self) -> int: ...
    def getColorTemperature(self) -> int: ...
    def getCvFrame(self) -> object: ...
    def getExposureTime(self) -> datetime.timedelta: ...
    def getFrame(self, copy: bool = ...) -> numpy.ndarray: ...
    def getHeight(self) -> int: ...
    def getInstanceNum(self) -> int: ...
    def getLensPosition(self) -> int: ...
    def getLensPositionRaw(self) -> float: ...
    def getPlaneHeight(self) -> int: ...
    def getPlaneStride(self, arg0: int) -> int: ...
    def getSensitivity(self) -> int: ...
    def getSequenceNum(self) -> int: ...
    def getStride(self) -> int: ...
    @overload
    def getTimestamp(self) -> datetime.timedelta: ...
    @overload
    def getTimestamp(self, offset: CameraExposureOffset) -> datetime.timedelta: ...
    @overload
    def getTimestampDevice(self) -> datetime.timedelta: ...
    @overload
    def getTimestampDevice(self, offset: CameraExposureOffset) -> datetime.timedelta: ...
    def getType(self) -> ImgFrame.Type: ...
    def getWidth(self) -> int: ...
    def setCategory(self, category: int) -> ImgFrame: ...
    def setFrame(self, array: numpy.ndarray) -> None: ...
    def setHeight(self, height: int) -> ImgFrame: ...
    def setInstanceNum(self, instance: int) -> ImgFrame: ...
    @overload
    def setSize(self, width: int, height: int) -> ImgFrame: ...
    @overload
    def setSize(self, sizer: Tuple[int,int]) -> ImgFrame: ...
    def setType(self, type: ImgFrame.Type) -> ImgFrame: ...
    def setWidth(self, width: int) -> ImgFrame: ...

class Interpolation:
    __members__: ClassVar[dict] = ...  # read-only
    BICUBIC: ClassVar[Interpolation] = ...
    BILINEAR: ClassVar[Interpolation] = ...
    BYPASS: ClassVar[Interpolation] = ...
    DEFAULT: ClassVar[Interpolation] = ...
    DEFAULT_DISPARITY_DEPTH: ClassVar[Interpolation] = ...
    NEAREST_NEIGHBOR: ClassVar[Interpolation] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class LogLevel:
    __members__: ClassVar[dict] = ...  # read-only
    CRITICAL: ClassVar[LogLevel] = ...
    DEBUG: ClassVar[LogLevel] = ...
    ERR: ClassVar[LogLevel] = ...
    INFO: ClassVar[LogLevel] = ...
    OFF: ClassVar[LogLevel] = ...
    TRACE: ClassVar[LogLevel] = ...
    WARN: ClassVar[LogLevel] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class LogMessage:
    colorRangeEnd: int
    colorRangeStart: int
    level: LogLevel
    nodeIdName: str
    payload: str
    time: Timestamp
    def __init__(self, *args, **kwargs) -> None: ...

class MedianFilter:
    __members__: ClassVar[dict] = ...  # read-only
    KERNEL_3x3: ClassVar[MedianFilter] = ...
    KERNEL_5x5: ClassVar[MedianFilter] = ...
    KERNEL_7x7: ClassVar[MedianFilter] = ...
    MEDIAN_OFF: ClassVar[MedianFilter] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class MemoryInfo:
    remaining: int
    total: int
    used: int
    def __init__(self) -> None: ...

class MessageDemuxProperties:
    def __init__(self, *args, **kwargs) -> None: ...

class MessageGroup(Buffer):
    def __init__(self) -> None: ...
    def getIntervalNs(self) -> int: ...
    def getMessageNames(self) -> List[str]: ...
    def getNumMessages(self) -> int: ...
    def getSequenceNum(self) -> int: ...
    def getTimestamp(self) -> datetime.timedelta: ...
    def getTimestampDevice(self) -> datetime.timedelta: ...
    def isSynced(self, arg0: int) -> bool: ...
    def __getitem__(self, arg0: str) -> ADatatype: ...
    def __iter__(self) -> Iterator: ...
    def __setitem__(self, arg0: str, arg1: ADatatype) -> None: ...

class MessageQueue:
    class QueueException(Exception): ...
    @overload
    def __init__(self, name: str) -> None: ...
    @overload
    def __init__(self, name: str = ..., maxSize: int = ..., blocking: bool = ...) -> None: ...
    def addCallback(self, callback: function) -> int: ...
    def close(self) -> None: ...
    def front(self) -> ADatatype: ...
    @overload
    def get(self) -> ADatatype: ...
    @overload
    def get(self, timeout: datetime.timedelta) -> ADatatype: ...
    def getAll(self) -> List[ADatatype]: ...
    def getBlocking(self) -> bool: ...
    def getMaxSize(self) -> int: ...
    @overload
    def getName(self) -> str: ...
    @overload
    def getName(self) -> str: ...
    def getSize(self) -> int: ...
    def has(self) -> bool: ...
    def isClosed(self) -> bool: ...
    def isFull(self) -> int: ...
    def removeCallback(self, callbackId: int) -> bool: ...
    @overload
    def send(self, msg: ADatatype) -> None: ...
    @overload
    def send(self, msg: ADatatype, timeout: datetime.timedelta) -> bool: ...
    def setBlocking(self, blocking: bool) -> None: ...
    def setMaxSize(self, maxSize: int) -> None: ...
    def setName(self, name: str) -> None: ...
    def tryGet(self) -> ADatatype: ...
    def tryGetAll(self) -> List[ADatatype]: ...
    def trySend(self, msg: ADatatype) -> bool: ...

class MonoCameraProperties:
    class SensorResolution:
        __members__: ClassVar[dict] = ...  # read-only
        THE_1200_P: ClassVar[MonoCameraProperties.SensorResolution] = ...
        THE_4000X3000: ClassVar[MonoCameraProperties.SensorResolution] = ...
        THE_400_P: ClassVar[MonoCameraProperties.SensorResolution] = ...
        THE_4224X3136: ClassVar[MonoCameraProperties.SensorResolution] = ...
        THE_480_P: ClassVar[MonoCameraProperties.SensorResolution] = ...
        THE_720_P: ClassVar[MonoCameraProperties.SensorResolution] = ...
        THE_800_P: ClassVar[MonoCameraProperties.SensorResolution] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    boardSocket: CameraBoardSocket
    eventFilter: List[FrameEvent]
    fps: float
    initialControl: CameraControl
    isp3aFps: int
    numFramesPool: int
    numFramesPoolRaw: int
    resolution: MonoCameraProperties.SensorResolution
    def __init__(self, *args, **kwargs) -> None: ...

class NNArchive:
    def __init__(self, path: Path, compression: NNArchiveEntry.Compression = ...) -> None: ...

class NNArchiveEntry:
    class Compression:
        __members__: ClassVar[dict] = ...  # read-only
        AUTO: ClassVar[NNArchiveEntry.Compression] = ...
        RAW_FS: ClassVar[NNArchiveEntry.Compression] = ...
        TAR: ClassVar[NNArchiveEntry.Compression] = ...
        TAR_GZ: ClassVar[NNArchiveEntry.Compression] = ...
        TAR_XZ: ClassVar[NNArchiveEntry.Compression] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    def __init__(self, *args, **kwargs) -> None: ...

class NNData(Buffer):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: int) -> None: ...
    @overload
    def addTensor(self, name: str, tensor: List[int]) -> NNData: ...
    @overload
    def addTensor(self, name: str, tensor: List[float]) -> NNData: ...
    @overload
    def addTensor(self, name: str, tensor: List[float]) -> NNData: ...
    @overload
    def addTensor(self, name: str, tensor: numpy.ndarray[numpy.int32]) -> NNData: ...
    @overload
    def addTensor(self, name: str, tensor: numpy.ndarray[numpy.float32]) -> NNData: ...
    @overload
    def addTensor(self, name: str, tensor: numpy.ndarray[numpy.float64]) -> NNData: ...
    def getAllLayerNames(self) -> List[str]: ...
    def getAllLayers(self) -> List[TensorInfo]: ...
    def getLayerDatatype(self, name: str, datatype: TensorInfo.DataType) -> bool: ...
    def getSequenceNum(self) -> int: ...
    def getTensor(self, name: str) -> object: ...
    def getTensorDatatype(self, name: str) -> TensorInfo.DataType: ...
    def getTimestamp(self) -> datetime.timedelta: ...
    def getTimestampDevice(self) -> datetime.timedelta: ...
    def hasLayer(self, name: str) -> bool: ...

class NeuralNetworkProperties:
    blobSize: Optional[int]
    blobUri: str
    numFrames: int
    numNCEPerThread: int
    numThreads: int
    def __init__(self, *args, **kwargs) -> None: ...

class Node:
    class Connection:
        inputGroup: str
        inputId: int
        inputName: str
        outputGroup: str
        outputId: int
        outputName: str
        def __init__(self, *args, **kwargs) -> None: ...

    class DatatypeHierarchy:
        datatype: DatatypeEnum
        descendants: bool
        def __init__(self, arg0: DatatypeEnum, arg1: bool) -> None: ...

    class Id:
        def __init__(self, *args, **kwargs) -> None: ...

    class Input(MessageQueue):
        class Type:
            __members__: ClassVar[dict] = ...  # read-only
            MReceiver: ClassVar[Node.Input.Type] = ...
            SReceiver: ClassVar[Node.Input.Type] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        possibleDatatypes: List[Node.DatatypeHierarchy]
        def __init__(self, parent: Node, name: str = ..., group: str = ..., blocking: bool = ..., queueSize: int = ..., types: List[Node.DatatypeHierarchy] = ..., waitForMessage: bool = ...) -> None: ...
        @overload
        def getParent(self) -> Node: ...
        @overload
        def getParent(self) -> Node: ...
        def getReusePreviousMessage(self) -> bool: ...
        def getWaitForMessage(self) -> bool: ...
        def setReusePreviousMessage(self, reusePreviousMessage: bool) -> None: ...
        def setWaitForMessage(self, waitForMessage: bool) -> None: ...

    class InputMap:
        def __init__(self, *args, **kwargs) -> None: ...
        def items(self) -> Iterator: ...
        def __bool__(self) -> bool: ...
        @overload
        def __contains__(self, arg0: str) -> bool: ...
        @overload
        def __contains__(self, arg0: Tuple[str,str]) -> bool: ...
        @overload
        def __delitem__(self, arg0: str) -> None: ...
        @overload
        def __delitem__(self, arg0: Tuple[str,str]) -> None: ...
        @overload
        def __getitem__(self, arg0: str) -> Node.Input: ...
        @overload
        def __getitem__(self, arg0: Tuple[str,str]) -> Node.Input: ...
        def __iter__(self) -> Iterator: ...
        def __len__(self) -> int: ...
        def __setitem__(self, arg0: Tuple[str,str], arg1: Node.Input) -> None: ...

    class Output:
        class Type:
            __members__: ClassVar[dict] = ...  # read-only
            MSender: ClassVar[Node.Output.Type] = ...
            SSender: ClassVar[Node.Output.Type] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        def __init__(self, parent: Node, name: str = ..., group: str = ..., possibleDatatypes: List[Node.DatatypeHierarchy] = ...) -> None: ...
        def canConnect(self, input: Node.Input) -> bool: ...
        def createQueue(self, maxSize: int = ..., blocking: bool = ...) -> MessageQueue: ...
        @overload
        def getParent(self) -> Node: ...
        @overload
        def getParent(self) -> Node: ...
        def getPossibleDatatypes(self) -> List[Node.DatatypeHierarchy]: ...
        def isSamePipeline(self, input: Node.Input) -> bool: ...
        def link(self, input: Node.Input) -> None: ...
        def send(self, msg: ADatatype) -> None: ...
        def trySend(self, msg: ADatatype) -> bool: ...
        def unlink(self, input: Node.Input) -> None: ...

    class OutputMap:
        def __init__(self, *args, **kwargs) -> None: ...
        def items(self) -> Iterator: ...
        def __bool__(self) -> bool: ...
        @overload
        def __contains__(self, arg0: str) -> bool: ...
        @overload
        def __contains__(self, arg0: Tuple[str,str]) -> bool: ...
        @overload
        def __delitem__(self, arg0: str) -> None: ...
        @overload
        def __delitem__(self, arg0: Tuple[str,str]) -> None: ...
        @overload
        def __getitem__(self, arg0: str) -> Node.Output: ...
        @overload
        def __getitem__(self, arg0: Tuple[str,str]) -> Node.Output: ...
        def __iter__(self) -> Iterator: ...
        def __len__(self) -> int: ...
        def __setitem__(self, arg0: Tuple[str,str], arg1: Node.Output) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    @overload
    def getAssetManager(self) -> AssetManager: ...
    @overload
    def getAssetManager(self) -> AssetManager: ...
    def getInputMapRefs(self) -> List[Node.InputMap]: ...
    @overload
    def getInputRefs(self) -> List[Node.Input]: ...
    @overload
    def getInputRefs(self) -> List[Node.Input]: ...
    def getInputs(self) -> List[Node.Input]: ...
    def getName(self) -> str: ...
    def getOutputMapRefs(self) -> List[Node.OutputMap]: ...
    @overload
    def getOutputRefs(self) -> List[Node.Output]: ...
    @overload
    def getOutputRefs(self) -> List[Node.Output]: ...
    def getOutputs(self) -> List[Node.Output]: ...
    @overload
    def getParentPipeline(self) -> Pipeline: ...
    @overload
    def getParentPipeline(self) -> Pipeline: ...
    def stopPipeline(self) -> None: ...
    @property
    def id(self) -> int: ...

class NodeGroup(Node):
    def __init__(self, *args, **kwargs) -> None: ...

class ObjectTrackerProperties:
    detectionLabelsToTrack: List[int]
    maxObjectsToTrack: int
    trackerIdAssignmentPolicy: TrackerIdAssignmentPolicy
    trackerThreshold: float
    trackerType: TrackerType
    def __init__(self, *args, **kwargs) -> None: ...

class OpenVINO:
    class Blob:
        data: List[int]
        device: OpenVINO.Device
        networkInputs: Dict[str,TensorInfo]
        networkOutputs: Dict[str,TensorInfo]
        numShaves: int
        numSlices: int
        stageCount: int
        version: OpenVINO.Version
        @overload
        def __init__(self, arg0: List[int]) -> None: ...
        @overload
        def __init__(self, arg0: Path) -> None: ...

    class Device:
        __members__: ClassVar[dict] = ...  # read-only
        VPU: ClassVar[OpenVINO.Device] = ...
        VPUX: ClassVar[OpenVINO.Device] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class Version:
        __members__: ClassVar[dict] = ...  # read-only
        VERSION_2020_3: ClassVar[OpenVINO.Version] = ...
        VERSION_2020_4: ClassVar[OpenVINO.Version] = ...
        VERSION_2021_1: ClassVar[OpenVINO.Version] = ...
        VERSION_2021_2: ClassVar[OpenVINO.Version] = ...
        VERSION_2021_3: ClassVar[OpenVINO.Version] = ...
        VERSION_2021_4: ClassVar[OpenVINO.Version] = ...
        VERSION_2022_1: ClassVar[OpenVINO.Version] = ...
        VERSION_UNIVERSAL: ClassVar[OpenVINO.Version] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    DEFAULT_VERSION: ClassVar[OpenVINO.Version] = ...
    VERSION_2020_3: ClassVar[OpenVINO.Version] = ...
    VERSION_2020_4: ClassVar[OpenVINO.Version] = ...
    VERSION_2021_1: ClassVar[OpenVINO.Version] = ...
    VERSION_2021_2: ClassVar[OpenVINO.Version] = ...
    VERSION_2021_3: ClassVar[OpenVINO.Version] = ...
    VERSION_2021_4: ClassVar[OpenVINO.Version] = ...
    VERSION_2022_1: ClassVar[OpenVINO.Version] = ...
    VERSION_UNIVERSAL: ClassVar[OpenVINO.Version] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    @classmethod
    def areVersionsBlobCompatible(cls, v1: OpenVINO.Version, v2: OpenVINO.Version) -> bool: ...
    @classmethod
    def getBlobLatestSupportedVersion(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def getBlobSupportedVersions(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def getVersionName(cls, version: OpenVINO.Version) -> str: ...
    @classmethod
    def getVersions(cls) -> List[OpenVINO.Version]: ...
    @classmethod
    def parseVersionName(cls, versionString: str) -> OpenVINO.Version: ...

class Pipeline:
    @overload
    def __init__(self, createImplicitDevice: bool = ...) -> None: ...
    @overload
    def __init__(self, defaultDevice: Device) -> None: ...
    def add(self, arg0: Node) -> Node: ...
    def create(self, arg0: Type[T], *args, **kwargs) -> T: ...
    def createAprilTag(self) -> node.AprilTag: ...
    def createCamera(self) -> node.Camera: ...
    def createColorCamera(self) -> node.ColorCamera: ...
    def createDetectionParser(self) -> node.DetectionParser: ...
    def createEdgeDetector(self) -> node.EdgeDetector: ...
    def createFeatureTracker(self) -> node.FeatureTracker: ...
    def createIMU(self) -> node.IMU: ...
    def createImageManip(self) -> node.ImageManip: ...
    def createMobileNetDetectionNetwork(self) -> node.MobileNetDetectionNetwork: ...
    def createMobileNetSpatialDetectionNetwork(self) -> node.MobileNetSpatialDetectionNetwork: ...
    def createMonoCamera(self) -> node.MonoCamera: ...
    def createNeuralNetwork(self) -> node.NeuralNetwork: ...
    def createObjectTracker(self) -> node.ObjectTracker: ...
    def createSPIIn(self) -> node.SPIIn: ...
    def createSPIOut(self) -> node.SPIOut: ...
    def createScript(self) -> node.Script: ...
    def createSpatialLocationCalculator(self) -> node.SpatialLocationCalculator: ...
    def createStereoDepth(self) -> node.StereoDepth: ...
    def createSystemLogger(self) -> node.SystemLogger: ...
    def createUVC(self) -> node.UVC: ...
    def createVideoEncoder(self) -> node.VideoEncoder: ...
    def createWarp(self) -> node.Warp: ...
    def createXLinkIn(self) -> node.XLinkIn: ...
    def createXLinkOut(self) -> node.XLinkOut: ...
    def createYoloDetectionNetwork(self) -> node.YoloDetectionNetwork: ...
    def createYoloSpatialDetectionNetwork(self) -> node.YoloSpatialDetectionNetwork: ...
    def getAllNodes(self) -> List[Node]: ...
    @overload
    def getAssetManager(self) -> AssetManager: ...
    @overload
    def getAssetManager(self) -> AssetManager: ...
    def getBoardConfig(self) -> BoardConfig: ...
    def getCalibrationData(self) -> CalibrationHandler: ...
    def getDeviceConfig(self) -> Device.Config: ...
    def getGlobalProperties(self) -> GlobalProperties: ...
    def getNode(self, arg0: int) -> Node: ...
    def getOpenVINOVersion(self) -> OpenVINO.Version: ...
    def getRequiredOpenVINOVersion(self) -> Optional[OpenVINO.Version]: ...
    def isRunning(self) -> bool: ...
    def processTasks(self) -> None: ...
    def remove(self, node: Node) -> None: ...
    def run(self) -> None: ...
    def serializeToJson(self) -> json: ...
    def setBoardConfig(self, arg0: BoardConfig) -> None: ...
    def setCalibrationData(self, calibrationDataHandler: CalibrationHandler) -> None: ...
    def setCameraTuningBlobPath(self, path: Path) -> None: ...
    def setOpenVINOVersion(self, version: OpenVINO.Version) -> None: ...
    def setSippBufferSize(self, sizeBytes: int) -> None: ...
    def setSippDmaBufferSize(self, sizeBytes: int) -> None: ...
    def setXLinkChunkSize(self, sizeBytes: int) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def wait(self) -> None: ...
    def __enter__(self) -> Pipeline: ...
    def __exit__(self, arg0: object, arg1: object, arg2: object) -> None: ...

class Point2f:
    x: float
    y: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float) -> None: ...

class Point3f:
    x: float
    y: float
    z: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float) -> None: ...

class PointCloudConfig(Buffer):
    def __init__(self) -> None: ...
    def getSparse(self) -> bool: ...
    def getTransformationMatrix(self) -> List[List[float[4]][4]]: ...
    def setSparse(self, arg0: bool) -> PointCloudConfig: ...
    @overload
    def setTransformationMatrix(self, arg0: List[List[float[3]][3]]) -> PointCloudConfig: ...
    @overload
    def setTransformationMatrix(self, arg0: List[List[float[4]][4]]) -> PointCloudConfig: ...

class PointCloudData(Buffer):
    def __init__(self) -> None: ...
    def getHeight(self) -> int: ...
    def getInstanceNum(self) -> int: ...
    def getMaxX(self) -> float: ...
    def getMaxY(self) -> float: ...
    def getMaxZ(self) -> float: ...
    def getMinX(self) -> float: ...
    def getMinY(self) -> float: ...
    def getMinZ(self) -> float: ...
    def getPoints(self) -> numpy.ndarray[numpy.float32]: ...
    def getSequenceNum(self) -> int: ...
    def getTimestamp(self) -> datetime.timedelta: ...
    def getTimestampDevice(self) -> datetime.timedelta: ...
    def getWidth(self) -> int: ...
    def isSparse(self) -> bool: ...
    def setHeight(self, arg0: int) -> PointCloudData: ...
    def setInstanceNum(self, arg0: int) -> PointCloudData: ...
    def setMaxX(self, arg0: float) -> PointCloudData: ...
    def setMaxY(self, arg0: float) -> PointCloudData: ...
    def setMaxZ(self, arg0: float) -> PointCloudData: ...
    def setMinX(self, arg0: float) -> PointCloudData: ...
    def setMinY(self, arg0: float) -> PointCloudData: ...
    def setMinZ(self, arg0: float) -> PointCloudData: ...
    @overload
    def setSize(self, width: int, height: int) -> PointCloudData: ...
    @overload
    def setSize(self, size: Tuple[int,int]) -> PointCloudData: ...
    def setWidth(self, arg0: int) -> PointCloudData: ...

class PointCloudProperties:
    initialConfig: PointCloudConfig
    numFramesPool: int
    def __init__(self, *args, **kwargs) -> None: ...

class ProcessorType:
    __members__: ClassVar[dict] = ...  # read-only
    LEON_CSS: ClassVar[ProcessorType] = ...
    LEON_MSS: ClassVar[ProcessorType] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class ProfilingData:
    numBytesRead: int
    numBytesWritten: int
    def __init__(self, *args, **kwargs) -> None: ...

class Properties:
    def __init__(self, *args, **kwargs) -> None: ...

class Rect:
    height: float
    width: float
    x: float
    y: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float) -> None: ...
    @overload
    def __init__(self, arg0: Point2f, arg1: Point2f) -> None: ...
    @overload
    def __init__(self, arg0: Point2f, arg1: Size2f) -> None: ...
    def area(self) -> float: ...
    def bottomRight(self) -> Point2f: ...
    def contains(self, arg0: Point2f) -> bool: ...
    def denormalize(self, width: int, height: int) -> Rect: ...
    def empty(self) -> bool: ...
    def isNormalized(self) -> bool: ...
    def normalize(self, width: int, height: int) -> Rect: ...
    def size(self) -> Size2f: ...
    def topLeft(self) -> Point2f: ...

class RotatedRect:
    angle: float
    center: Point2f
    size: Size2f
    def __init__(self) -> None: ...

class SPIInProperties:
    busId: int
    maxDataSize: int
    numFrames: int
    streamName: str
    def __init__(self, *args, **kwargs) -> None: ...

class SPIOutProperties:
    busId: int
    streamName: str
    def __init__(self, *args, **kwargs) -> None: ...

class ScriptProperties:
    processor: ProcessorType
    scriptName: str
    scriptUri: str
    def __init__(self, *args, **kwargs) -> None: ...

class SerializationType:
    __members__: ClassVar[dict] = ...  # read-only
    JSON: ClassVar[SerializationType] = ...
    JSON_MSGPACK: ClassVar[SerializationType] = ...
    LIBNOP: ClassVar[SerializationType] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class Size2f:
    height: float
    width: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float) -> None: ...

class SpatialDetectionNetworkProperties:
    depthThresholds: SpatialLocationCalculatorConfigThresholds
    detectedBBScaleFactor: float
    def __init__(self, *args, **kwargs) -> None: ...

class SpatialImgDetection(ImgDetection):
    boundingBoxMapping: SpatialLocationCalculatorConfigData
    spatialCoordinates: Point3f
    def __init__(self) -> None: ...

class SpatialImgDetections(Buffer):
    detections: List[SpatialImgDetection]
    def __init__(self) -> None: ...
    def getSequenceNum(self) -> int: ...
    def getTimestamp(self) -> datetime.timedelta: ...
    def getTimestampDevice(self) -> datetime.timedelta: ...

class SpatialLocationCalculatorAlgorithm:
    __members__: ClassVar[dict] = ...  # read-only
    AVERAGE: ClassVar[SpatialLocationCalculatorAlgorithm] = ...
    MAX: ClassVar[SpatialLocationCalculatorAlgorithm] = ...
    MEAN: ClassVar[SpatialLocationCalculatorAlgorithm] = ...
    MEDIAN: ClassVar[SpatialLocationCalculatorAlgorithm] = ...
    MIN: ClassVar[SpatialLocationCalculatorAlgorithm] = ...
    MODE: ClassVar[SpatialLocationCalculatorAlgorithm] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class SpatialLocationCalculatorConfig(Buffer):
    def __init__(self) -> None: ...
    def addROI(self, ROI: SpatialLocationCalculatorConfigData) -> None: ...
    def getConfigData(self) -> List[SpatialLocationCalculatorConfigData]: ...
    def setROIs(self, ROIs: List[SpatialLocationCalculatorConfigData]) -> None: ...

class SpatialLocationCalculatorConfigData:
    calculationAlgorithm: SpatialLocationCalculatorAlgorithm
    depthThresholds: SpatialLocationCalculatorConfigThresholds
    roi: Rect
    def __init__(self) -> None: ...

class SpatialLocationCalculatorConfigThresholds:
    lowerThreshold: int
    upperThreshold: int
    def __init__(self) -> None: ...

class SpatialLocationCalculatorData(Buffer):
    spatialLocations: List[SpatialLocations]
    def __init__(self) -> None: ...
    def getSequenceNum(self) -> int: ...
    def getSpatialLocations(self) -> List[SpatialLocations]: ...
    def getTimestamp(self) -> datetime.timedelta: ...
    def getTimestampDevice(self) -> datetime.timedelta: ...

class SpatialLocationCalculatorProperties:
    roiConfig: SpatialLocationCalculatorConfig
    def __init__(self, *args, **kwargs) -> None: ...

class SpatialLocations:
    config: SpatialLocationCalculatorConfigData
    depthAverage: float
    depthAveragePixelCount: int
    depthMax: int
    depthMedian: float
    depthMin: int
    depthMode: float
    spatialCoordinates: Point3f
    def __init__(self) -> None: ...

class StereoDepthConfig(Buffer):
    class AlgorithmControl:
        class DepthAlign:
            __members__: ClassVar[dict] = ...  # read-only
            CENTER: ClassVar[StereoDepthConfig.AlgorithmControl.DepthAlign] = ...
            RECTIFIED_LEFT: ClassVar[StereoDepthConfig.AlgorithmControl.DepthAlign] = ...
            RECTIFIED_RIGHT: ClassVar[StereoDepthConfig.AlgorithmControl.DepthAlign] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class DepthUnit:
            __members__: ClassVar[dict] = ...  # read-only
            CENTIMETER: ClassVar[StereoDepthConfig.AlgorithmControl.DepthUnit] = ...
            CUSTOM: ClassVar[StereoDepthConfig.AlgorithmControl.DepthUnit] = ...
            FOOT: ClassVar[StereoDepthConfig.AlgorithmControl.DepthUnit] = ...
            INCH: ClassVar[StereoDepthConfig.AlgorithmControl.DepthUnit] = ...
            METER: ClassVar[StereoDepthConfig.AlgorithmControl.DepthUnit] = ...
            MILLIMETER: ClassVar[StereoDepthConfig.AlgorithmControl.DepthUnit] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        centerAlignmentShiftFactor: Optional[float]
        customDepthUnitMultiplier: float
        depthAlign: StereoDepthConfig.AlgorithmControl.DepthAlign
        depthUnit: StereoDepthConfig.AlgorithmControl.DepthUnit
        disparityShift: int
        enableExtended: bool
        enableLeftRightCheck: bool
        enableSubpixel: bool
        leftRightCheckThreshold: int
        numInvalidateEdgePixels: int
        outlierCensusThreshold: int
        outlierDiffThreshold: int
        outlierRemoveThreshold: int
        replaceInvalidDisparity: bool
        subpixelFractionalBits: int
        def __init__(self) -> None: ...

    class CensusTransform:
        class KernelSize:
            __members__: ClassVar[dict] = ...  # read-only
            AUTO: ClassVar[StereoDepthConfig.CensusTransform.KernelSize] = ...
            KERNEL_5x5: ClassVar[StereoDepthConfig.CensusTransform.KernelSize] = ...
            KERNEL_7x7: ClassVar[StereoDepthConfig.CensusTransform.KernelSize] = ...
            KERNEL_7x9: ClassVar[StereoDepthConfig.CensusTransform.KernelSize] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        enableMeanMode: bool
        kernelMask: int
        kernelSize: StereoDepthConfig.CensusTransform.KernelSize
        threshold: int
        def __init__(self) -> None: ...

    class CostAggregation:
        class LocalAggregationMode:
            __members__: ClassVar[dict] = ...  # read-only
            AVG3x3: ClassVar[StereoDepthConfig.CostAggregation.LocalAggregationMode] = ...
            CLAMP3x3: ClassVar[StereoDepthConfig.CostAggregation.LocalAggregationMode] = ...
            PASS3x3: ClassVar[StereoDepthConfig.CostAggregation.LocalAggregationMode] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        divisionFactor: int
        horizontalPenaltyCostP1: int
        horizontalPenaltyCostP2: int
        localAggregationMode: StereoDepthConfig.CostAggregation.LocalAggregationMode
        verticalPenaltyCostP1: int
        verticalPenaltyCostP2: int
        def __init__(self) -> None: ...

    class CostMatching:
        class DisparityWidth:
            __members__: ClassVar[dict] = ...  # read-only
            DISPARITY_64: ClassVar[StereoDepthConfig.CostMatching.DisparityWidth] = ...
            DISPARITY_96: ClassVar[StereoDepthConfig.CostMatching.DisparityWidth] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class LinearEquationParameters:
            alpha: int
            beta: int
            threshold: int
            def __init__(self) -> None: ...
        confidenceThreshold: int
        disparityWidth: StereoDepthConfig.CostMatching.DisparityWidth
        enableCompanding: bool
        invalidDisparityValue: int
        linearEquationParameters: StereoDepthConfig.CostMatching.LinearEquationParameters
        def __init__(self) -> None: ...

    class MedianFilter:
        __members__: ClassVar[dict] = ...  # read-only
        KERNEL_3x3: ClassVar[MedianFilter] = ...
        KERNEL_5x5: ClassVar[MedianFilter] = ...
        KERNEL_7x7: ClassVar[MedianFilter] = ...
        MEDIAN_OFF: ClassVar[MedianFilter] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class PostProcessing:
        class BrightnessFilter:
            maxBrightness: int
            minBrightness: int
            def __init__(self) -> None: ...
    
        class DecimationFilter:
            class DecimationMode:
                __members__: ClassVar[dict] = ...  # read-only
                NON_ZERO_MEAN: ClassVar[StereoDepthConfig.PostProcessing.DecimationFilter.DecimationMode] = ...
                NON_ZERO_MEDIAN: ClassVar[StereoDepthConfig.PostProcessing.DecimationFilter.DecimationMode] = ...
                PIXEL_SKIPPING: ClassVar[StereoDepthConfig.PostProcessing.DecimationFilter.DecimationMode] = ...
                __entries: ClassVar[dict] = ...
                def __init__(self, value: int) -> None: ...
                def __eq__(self, other: object) -> bool: ...
                def __getstate__(self) -> int: ...
                def __hash__(self) -> int: ...
                def __index__(self) -> int: ...
                def __int__(self) -> int: ...
                def __ne__(self, other: object) -> bool: ...
                def __setstate__(self, state: int) -> None: ...
                @property
                def name(self) -> str: ...
                @property
                def value(self) -> int: ...
            decimationFactor: int
            decimationMode: StereoDepthConfig.PostProcessing.DecimationFilter.DecimationMode
            def __init__(self) -> None: ...
    
        class SpatialFilter:
            alpha: float
            delta: int
            enable: bool
            holeFillingRadius: int
            numIterations: int
            def __init__(self) -> None: ...
    
        class SpeckleFilter:
            enable: bool
            speckleRange: int
            def __init__(self) -> None: ...
    
        class TemporalFilter:
            class PersistencyMode:
                __members__: ClassVar[dict] = ...  # read-only
                PERSISTENCY_INDEFINITELY: ClassVar[StereoDepthConfig.PostProcessing.TemporalFilter.PersistencyMode] = ...
                PERSISTENCY_OFF: ClassVar[StereoDepthConfig.PostProcessing.TemporalFilter.PersistencyMode] = ...
                VALID_1_IN_LAST_2: ClassVar[StereoDepthConfig.PostProcessing.TemporalFilter.PersistencyMode] = ...
                VALID_1_IN_LAST_5: ClassVar[StereoDepthConfig.PostProcessing.TemporalFilter.PersistencyMode] = ...
                VALID_1_IN_LAST_8: ClassVar[StereoDepthConfig.PostProcessing.TemporalFilter.PersistencyMode] = ...
                VALID_2_IN_LAST_3: ClassVar[StereoDepthConfig.PostProcessing.TemporalFilter.PersistencyMode] = ...
                VALID_2_IN_LAST_4: ClassVar[StereoDepthConfig.PostProcessing.TemporalFilter.PersistencyMode] = ...
                VALID_2_OUT_OF_8: ClassVar[StereoDepthConfig.PostProcessing.TemporalFilter.PersistencyMode] = ...
                VALID_8_OUT_OF_8: ClassVar[StereoDepthConfig.PostProcessing.TemporalFilter.PersistencyMode] = ...
                __entries: ClassVar[dict] = ...
                def __init__(self, value: int) -> None: ...
                def __eq__(self, other: object) -> bool: ...
                def __getstate__(self) -> int: ...
                def __hash__(self) -> int: ...
                def __index__(self) -> int: ...
                def __int__(self) -> int: ...
                def __ne__(self, other: object) -> bool: ...
                def __setstate__(self, state: int) -> None: ...
                @property
                def name(self) -> str: ...
                @property
                def value(self) -> int: ...
            alpha: float
            delta: int
            enable: bool
            persistencyMode: StereoDepthConfig.PostProcessing.TemporalFilter.PersistencyMode
            def __init__(self) -> None: ...
    
        class ThresholdFilter:
            maxRange: int
            minRange: int
            def __init__(self) -> None: ...
        bilateralSigmaValue: int
        brightnessFilter: StereoDepthConfig.PostProcessing.BrightnessFilter
        decimationFilter: StereoDepthConfig.PostProcessing.DecimationFilter
        median: MedianFilter
        spatialFilter: StereoDepthConfig.PostProcessing.SpatialFilter
        speckleFilter: StereoDepthConfig.PostProcessing.SpeckleFilter
        temporalFilter: StereoDepthConfig.PostProcessing.TemporalFilter
        thresholdFilter: StereoDepthConfig.PostProcessing.ThresholdFilter
        def __init__(self) -> None: ...
    algorithmControl: StereoDepthConfig.AlgorithmControl
    censusTransform: StereoDepthConfig.CensusTransform
    costAggregation: StereoDepthConfig.CostAggregation
    costMatching: StereoDepthConfig.CostMatching
    postProcessing: StereoDepthConfig.PostProcessing
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def getBilateralFilterSigma(self) -> int: ...
    def getConfidenceThreshold(self) -> int: ...
    def getDepthUnit(self) -> StereoDepthConfig.AlgorithmControl.DepthUnit: ...
    def getLeftRightCheckThreshold(self) -> int: ...
    def getMaxDisparity(self) -> float: ...
    def getMedianFilter(self) -> MedianFilter: ...
    def setBilateralFilterSigma(self, sigma: int) -> StereoDepthConfig: ...
    def setConfidenceThreshold(self, confThr: int) -> StereoDepthConfig: ...
    def setDepthAlign(self, align: StereoDepthConfig.AlgorithmControl.DepthAlign) -> StereoDepthConfig: ...
    def setDepthUnit(self, arg0: StereoDepthConfig.AlgorithmControl.DepthUnit) -> StereoDepthConfig: ...
    def setDisparityShift(self, arg0: int) -> StereoDepthConfig: ...
    def setExtendedDisparity(self, enable: bool) -> StereoDepthConfig: ...
    def setLeftRightCheck(self, enable: bool) -> StereoDepthConfig: ...
    def setLeftRightCheckThreshold(self, sigma: int) -> StereoDepthConfig: ...
    def setMedianFilter(self, median: MedianFilter) -> StereoDepthConfig: ...
    def setNumInvalidateEdgePixels(self, arg0: int) -> StereoDepthConfig: ...
    def setSubpixel(self, enable: bool) -> StereoDepthConfig: ...
    def setSubpixelFractionalBits(self, subpixelFractionalBits: int) -> StereoDepthConfig: ...

class StereoDepthProperties:
    class RectificationMesh:
        meshLeftUri: str
        meshRightUri: str
        meshSize: Optional[int]
        stepHeight: int
        stepWidth: int
        def __init__(self, *args, **kwargs) -> None: ...
    alphaScaling: Optional[float]
    baseline: Optional[float]
    depthAlignCamera: CameraBoardSocket
    depthAlignmentUseSpecTranslation: Optional[bool]
    disparityToDepthUseSpecTranslation: Optional[bool]
    enableRectification: bool
    enableRuntimeStereoModeSwitch: bool
    focalLength: Optional[float]
    focalLengthFromCalibration: bool
    height: Optional[int]
    initialConfig: StereoDepthConfig
    mesh: StereoDepthProperties.RectificationMesh
    numFramesPool: int
    numPostProcessingMemorySlices: int
    numPostProcessingShaves: int
    outHeight: Optional[int]
    outKeepAspectRatio: bool
    outWidth: Optional[int]
    rectificationUseSpecTranslation: Optional[bool]
    rectifyEdgeFillColor: int
    useHomographyRectification: Optional[bool]
    width: Optional[int]
    def __init__(self, *args, **kwargs) -> None: ...

class StereoPair:
    baseline: float
    isVertical: bool
    left: CameraBoardSocket
    right: CameraBoardSocket
    def __init__(self) -> None: ...

class StereoRectification:
    leftCameraSocket: CameraBoardSocket
    rectifiedRotationLeft: List[List[float]]
    rectifiedRotationRight: List[List[float]]
    rightCameraSocket: CameraBoardSocket
    def __init__(self) -> None: ...

class SyncProperties:
    syncAttempts: int
    syncThresholdNs: int
    def __init__(self, *args, **kwargs) -> None: ...

class SystemInformation(Buffer):
    chipTemperature: ChipTemperature
    cmxMemoryUsage: MemoryInfo
    ddrMemoryUsage: MemoryInfo
    leonCssCpuUsage: CpuUsage
    leonCssMemoryUsage: MemoryInfo
    leonMssCpuUsage: CpuUsage
    leonMssMemoryUsage: MemoryInfo
    def __init__(self) -> None: ...

class SystemInformationS3(Buffer):
    chipTemperature: ChipTemperatureS3
    cpuAvgUsage: CpuUsage
    cpuUsages: List[CpuUsage]
    ddrMemoryUsage: MemoryInfo
    def __init__(self) -> None: ...

class SystemLoggerProperties:
    rateHz: float
    def __init__(self, *args, **kwargs) -> None: ...

class TensorInfo:
    class DataType:
        __members__: ClassVar[dict] = ...  # read-only
        FP16: ClassVar[TensorInfo.DataType] = ...
        FP32: ClassVar[TensorInfo.DataType] = ...
        I8: ClassVar[TensorInfo.DataType] = ...
        INT: ClassVar[TensorInfo.DataType] = ...
        U8F: ClassVar[TensorInfo.DataType] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class StorageOrder:
        __members__: ClassVar[dict] = ...  # read-only
        C: ClassVar[TensorInfo.StorageOrder] = ...
        CHW: ClassVar[TensorInfo.StorageOrder] = ...
        CN: ClassVar[TensorInfo.StorageOrder] = ...
        CWH: ClassVar[TensorInfo.StorageOrder] = ...
        H: ClassVar[TensorInfo.StorageOrder] = ...
        HCW: ClassVar[TensorInfo.StorageOrder] = ...
        HWC: ClassVar[TensorInfo.StorageOrder] = ...
        NC: ClassVar[TensorInfo.StorageOrder] = ...
        NCHW: ClassVar[TensorInfo.StorageOrder] = ...
        NHCW: ClassVar[TensorInfo.StorageOrder] = ...
        NHWC: ClassVar[TensorInfo.StorageOrder] = ...
        W: ClassVar[TensorInfo.StorageOrder] = ...
        WCH: ClassVar[TensorInfo.StorageOrder] = ...
        WHC: ClassVar[TensorInfo.StorageOrder] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    dataType: TensorInfo.DataType
    dims: List[int]
    name: str
    numDimensions: int
    offset: int
    order: TensorInfo.StorageOrder
    strides: List[int]
    def __init__(self) -> None: ...

class ThreadedNode(Node):
    def __init__(self, *args, **kwargs) -> None: ...
    def critical(self, arg0: str) -> None: ...
    def debug(self, arg0: str) -> None: ...
    def error(self, arg0: str) -> None: ...
    def info(self, arg0: str) -> None: ...
    def isRunning(self) -> bool: ...
    def trace(self, arg0: str) -> None: ...
    def warn(self, arg0: str) -> None: ...

class Timestamp:
    nsec: int
    sec: int
    def __init__(self) -> None: ...
    def get(self) -> datetime.timedelta: ...

class ToFConfig(Buffer):
    class DepthParams:
        class TypeFMod:
            __members__: ClassVar[dict] = ...  # read-only
            ALL: ClassVar[ToFConfig.DepthParams.TypeFMod] = ...
            MAX: ClassVar[ToFConfig.DepthParams.TypeFMod] = ...
            MIN: ClassVar[ToFConfig.DepthParams.TypeFMod] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        avgPhaseShuffle: bool
        freqModUsed: ToFConfig.DepthParams.TypeFMod
        median: Any
        minimumAmplitude: float
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...
    def setAvgPhaseShuffle(self, arg0: bool) -> ToFConfig: ...
    def setDepthParams(self, config: ToFConfig.DepthParams) -> ToFConfig: ...
    def setFreqModUsed(self, arg0: ToFConfig.DepthParams.TypeFMod) -> ToFConfig: ...
    def setMedianFilter(self, arg0) -> ToFConfig: ...
    def setMinAmplitude(self, arg0: float) -> ToFConfig: ...

class ToFProperties:
    initialConfig: ToFConfig
    def __init__(self, *args, **kwargs) -> None: ...

class TrackedFeature:
    age: int
    harrisScore: float
    id: int
    position: Point2f
    trackingError: float
    def __init__(self) -> None: ...

class TrackedFeatures(Buffer):
    trackedFeatures: List[TrackedFeature]
    def __init__(self) -> None: ...
    def getSequenceNum(self) -> int: ...
    def getTimestamp(self) -> datetime.timedelta: ...
    def getTimestampDevice(self) -> datetime.timedelta: ...

class TrackerIdAssignmentPolicy:
    __members__: ClassVar[dict] = ...  # read-only
    SMALLEST_ID: ClassVar[TrackerIdAssignmentPolicy] = ...
    UNIQUE_ID: ClassVar[TrackerIdAssignmentPolicy] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TrackerType:
    __members__: ClassVar[dict] = ...  # read-only
    SHORT_TERM_IMAGELESS: ClassVar[TrackerType] = ...
    SHORT_TERM_KCF: ClassVar[TrackerType] = ...
    ZERO_TERM_COLOR_HISTOGRAM: ClassVar[TrackerType] = ...
    ZERO_TERM_IMAGELESS: ClassVar[TrackerType] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class Tracklet:
    class TrackingStatus:
        __members__: ClassVar[dict] = ...  # read-only
        LOST: ClassVar[Tracklet.TrackingStatus] = ...
        NEW: ClassVar[Tracklet.TrackingStatus] = ...
        REMOVED: ClassVar[Tracklet.TrackingStatus] = ...
        TRACKED: ClassVar[Tracklet.TrackingStatus] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    age: int
    id: int
    label: int
    roi: Rect
    spatialCoordinates: Point3f
    srcImgDetection: ImgDetection
    status: Tracklet.TrackingStatus
    def __init__(self) -> None: ...

class Tracklets(Buffer):
    tracklets: List[Tracklet]
    def __init__(self) -> None: ...
    def getSequenceNum(self) -> int: ...
    def getTimestamp(self) -> datetime.timedelta: ...
    def getTimestampDevice(self) -> datetime.timedelta: ...

class UVCProperties:
    gpioInit: Dict[int,int]
    gpioStreamOff: Dict[int,int]
    gpioStreamOn: Dict[int,int]
    def __init__(self, *args, **kwargs) -> None: ...

class UsbSpeed:
    __members__: ClassVar[dict] = ...  # read-only
    FULL: ClassVar[UsbSpeed] = ...
    HIGH: ClassVar[UsbSpeed] = ...
    LOW: ClassVar[UsbSpeed] = ...
    SUPER: ClassVar[UsbSpeed] = ...
    SUPER_PLUS: ClassVar[UsbSpeed] = ...
    UNKNOWN: ClassVar[UsbSpeed] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class Version:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self, v: str) -> None: ...
    @overload
    def __init__(self, major: int, minor: int, patch: int) -> None: ...
    def getBuildInfo(self) -> str: ...
    def getSemver(self) -> Version: ...
    def toStringSemver(self) -> str: ...
    def __eq__(self, arg0: Version) -> bool: ...
    def __gt__(self, arg0: Version) -> bool: ...
    def __lt__(self, arg0: Version) -> bool: ...

class VideoEncoderProperties:
    class Profile:
        __members__: ClassVar[dict] = ...  # read-only
        H264_BASELINE: ClassVar[VideoEncoderProperties.Profile] = ...
        H264_HIGH: ClassVar[VideoEncoderProperties.Profile] = ...
        H264_MAIN: ClassVar[VideoEncoderProperties.Profile] = ...
        H265_MAIN: ClassVar[VideoEncoderProperties.Profile] = ...
        MJPEG: ClassVar[VideoEncoderProperties.Profile] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class RateControlMode:
        __members__: ClassVar[dict] = ...  # read-only
        CBR: ClassVar[VideoEncoderProperties.RateControlMode] = ...
        VBR: ClassVar[VideoEncoderProperties.RateControlMode] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    bitrate: int
    keyframeFrequency: int
    maxBitrate: int
    numBFrames: int
    numFramesPool: int
    outputFrameSize: int
    profile: VideoEncoderProperties.Profile
    quality: int
    rateCtrlMode: VideoEncoderProperties.RateControlMode
    def __init__(self, *args, **kwargs) -> None: ...

class WarpProperties:
    def __init__(self, *args, **kwargs) -> None: ...

class XLinkConnection:
    @overload
    def __init__(self, arg0: DeviceInfo, arg1: List[int]) -> None: ...
    @overload
    def __init__(self, arg0: DeviceInfo, arg1: str) -> None: ...
    @overload
    def __init__(self, arg0: DeviceInfo) -> None: ...
    @classmethod
    def bootBootloader(cls, devInfo: DeviceInfo) -> DeviceInfo: ...
    @classmethod
    def getAllConnectedDevices(cls, state: XLinkDeviceState = ..., skipInvalidDevices: bool = ...) -> List[DeviceInfo]: ...
    @classmethod
    def getDeviceByMxId(cls, mxId: str, state: XLinkDeviceState = ..., skipInvalidDevice: bool = ...) -> Tuple[bool,DeviceInfo]: ...
    @classmethod
    def getFirstDevice(cls, state: XLinkDeviceState = ..., skipInvalidDevice: bool = ...) -> Tuple[bool,DeviceInfo]: ...
    @classmethod
    def getGlobalProfilingData(cls) -> ProfilingData: ...

class XLinkDeviceState:
    __members__: ClassVar[dict] = ...  # read-only
    X_LINK_ANY_STATE: ClassVar[XLinkDeviceState] = ...
    X_LINK_BOOTED: ClassVar[XLinkDeviceState] = ...
    X_LINK_BOOTED_NON_EXCLUSIVE: ClassVar[XLinkDeviceState] = ...
    X_LINK_BOOTLOADER: ClassVar[XLinkDeviceState] = ...
    X_LINK_FLASH_BOOTED: ClassVar[XLinkDeviceState] = ...
    X_LINK_GATE: ClassVar[XLinkDeviceState] = ...
    X_LINK_GATE_BOOTED: ClassVar[XLinkDeviceState] = ...
    X_LINK_UNBOOTED: ClassVar[XLinkDeviceState] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class XLinkError(RuntimeError): ...

class XLinkError_t:
    __members__: ClassVar[dict] = ...  # read-only
    X_LINK_ALREADY_OPEN: ClassVar[XLinkError_t] = ...
    X_LINK_COMMUNICATION_FAIL: ClassVar[XLinkError_t] = ...
    X_LINK_COMMUNICATION_NOT_OPEN: ClassVar[XLinkError_t] = ...
    X_LINK_COMMUNICATION_UNKNOWN_ERROR: ClassVar[XLinkError_t] = ...
    X_LINK_DEVICE_ALREADY_IN_USE: ClassVar[XLinkError_t] = ...
    X_LINK_DEVICE_NOT_FOUND: ClassVar[XLinkError_t] = ...
    X_LINK_ERROR: ClassVar[XLinkError_t] = ...
    X_LINK_INIT_PCIE_ERROR: ClassVar[XLinkError_t] = ...
    X_LINK_INIT_TCP_IP_ERROR: ClassVar[XLinkError_t] = ...
    X_LINK_INIT_USB_ERROR: ClassVar[XLinkError_t] = ...
    X_LINK_INSUFFICIENT_PERMISSIONS: ClassVar[XLinkError_t] = ...
    X_LINK_NOT_IMPLEMENTED: ClassVar[XLinkError_t] = ...
    X_LINK_OUT_OF_MEMORY: ClassVar[XLinkError_t] = ...
    X_LINK_SUCCESS: ClassVar[XLinkError_t] = ...
    X_LINK_TIMEOUT: ClassVar[XLinkError_t] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class XLinkInProperties:
    maxDataSize: int
    numFrames: int
    streamName: str
    def __init__(self, *args, **kwargs) -> None: ...

class XLinkOutProperties:
    maxFpsLimit: float
    metadataOnly: bool
    streamName: str
    def __init__(self, *args, **kwargs) -> None: ...

class XLinkPlatform:
    __members__: ClassVar[dict] = ...  # read-only
    X_LINK_ANY_PLATFORM: ClassVar[XLinkPlatform] = ...
    X_LINK_MYRIAD_2: ClassVar[XLinkPlatform] = ...
    X_LINK_MYRIAD_X: ClassVar[XLinkPlatform] = ...
    X_LINK_RVC3: ClassVar[XLinkPlatform] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class XLinkProtocol:
    __members__: ClassVar[dict] = ...  # read-only
    X_LINK_ANY_PROTOCOL: ClassVar[XLinkProtocol] = ...
    X_LINK_IPC: ClassVar[XLinkProtocol] = ...
    X_LINK_NMB_OF_PROTOCOLS: ClassVar[XLinkProtocol] = ...
    X_LINK_PCIE: ClassVar[XLinkProtocol] = ...
    X_LINK_TCP_IP: ClassVar[XLinkProtocol] = ...
    X_LINK_USB_CDC: ClassVar[XLinkProtocol] = ...
    X_LINK_USB_VSC: ClassVar[XLinkProtocol] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class XLinkReadError(XLinkError): ...

class XLinkWriteError(XLinkError): ...

class connectionInterface:
    __members__: ClassVar[dict] = ...  # read-only
    ETHERNET: ClassVar[connectionInterface] = ...
    USB: ClassVar[connectionInterface] = ...
    WIFI: ClassVar[connectionInterface] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

def isDatatypeSubclassOf(arg0: DatatypeEnum, arg1: DatatypeEnum) -> bool: ...


from pathlib import Path
from typing import Set
from typing import Any, ClassVar, Dict, List, Optional, Tuple

from typing import overload
import datetime
import depthai

class AprilTag(depthai.DeviceNode):
    class Properties:
        initialConfig: depthai.AprilTagConfig
        inputConfigSync: bool
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def setWaitForConfigInput(self, wait: bool) -> None: ...
    @property
    def initialConfig(self) -> depthai.AprilTagConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputImage(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def passthroughInputImage(self) -> depthai.Node.Output: ...

class BenchmarkIn(depthai.DeviceNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def setNumMessagesToGet(self, num: int) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def passthrough(self) -> depthai.Node.Output: ...
    @property
    def report(self) -> depthai.Node.Output: ...

class BenchmarkOut(depthai.DeviceNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def setFps(self, fps: float) -> None: ...
    def setNumMessagesToSend(self, num: int) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class Camera(depthai.DeviceNode):
    class Properties:
        class ColorOrder:
            __members__: ClassVar[dict] = ...  # read-only
            BGR: ClassVar[depthai.CameraProperties.ColorOrder] = ...
            RGB: ClassVar[depthai.CameraProperties.ColorOrder] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class WarpMeshSource:
            __members__: ClassVar[dict] = ...  # read-only
            AUTO: ClassVar[depthai.CameraProperties.WarpMeshSource] = ...
            CALIBRATION: ClassVar[depthai.CameraProperties.WarpMeshSource] = ...
            NONE: ClassVar[depthai.CameraProperties.WarpMeshSource] = ...
            URI: ClassVar[depthai.CameraProperties.WarpMeshSource] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        boardSocket: depthai.CameraBoardSocket
        calibAlpha: Optional[float]
        cameraName: str
        colorOrder: depthai.CameraProperties.ColorOrder
        fp16: bool
        fps: float
        imageOrientation: depthai.CameraImageOrientation
        initialControl: depthai.CameraControl
        interleaved: bool
        isp3aFps: int
        ispScale: Any
        numFramesPoolIsp: int
        numFramesPoolPreview: int
        numFramesPoolRaw: int
        numFramesPoolStill: int
        numFramesPoolVideo: int
        previewHeight: int
        previewKeepAspectRatio: bool
        previewWidth: int
        rawPacked: Optional[bool]
        resolutionHeight: int
        resolutionWidth: int
        sensorCropX: float
        sensorCropY: float
        sensorType: depthai.CameraSensorType
        stillHeight: int
        stillWidth: int
        videoHeight: int
        videoWidth: int
        warpMeshHeight: int
        warpMeshSource: depthai.CameraProperties.WarpMeshSource
        warpMeshStepHeight: int
        warpMeshStepWidth: int
        warpMeshUri: str
        warpMeshWidth: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, boardSocket: depthai.CameraBoardSocket = ..., imageOrientation: depthai.CameraImageOrientation = ..., colorOrder: depthai.CameraProperties.ColorOrder = ..., interleaved: bool = ..., previewSize: Tuple[int,int] = ..., videoSize: Tuple[int,int] = ..., fps: float = ...) -> None: ...
    def build(self, boardSocket: depthai.CameraBoardSocket = ..., imageOrientation: depthai.CameraImageOrientation = ..., colorOrder: depthai.CameraProperties.ColorOrder = ..., interleaved: bool = ..., previewSize: Tuple[int,int] = ..., videoSize: Tuple[int,int] = ..., fps: float = ...) -> Camera: ...
    def getBoardSocket(self) -> depthai.CameraBoardSocket: ...
    def getCalibrationAlpha(self) -> Optional[float]: ...
    def getCamera(self) -> str: ...
    def getFps(self) -> float: ...
    def getHeight(self) -> int: ...
    def getImageOrientation(self) -> depthai.CameraImageOrientation: ...
    def getMeshSource(self) -> depthai.CameraProperties.WarpMeshSource: ...
    def getMeshStep(self) -> Tuple[int,int]: ...
    def getPreviewHeight(self) -> int: ...
    def getPreviewSize(self) -> Tuple[int,int]: ...
    def getPreviewWidth(self) -> int: ...
    def getSize(self) -> Tuple[int,int]: ...
    def getStillHeight(self) -> int: ...
    def getStillSize(self) -> Tuple[int,int]: ...
    def getStillWidth(self) -> int: ...
    def getVideoHeight(self) -> int: ...
    def getVideoSize(self) -> Tuple[int,int]: ...
    def getVideoWidth(self) -> int: ...
    def getWidth(self) -> int: ...
    def loadMeshData(self, warpMesh: buffer) -> None: ...
    def loadMeshFile(self, warpMesh: Path) -> None: ...
    def setBoardSocket(self, boardSocket: depthai.CameraBoardSocket) -> None: ...
    def setCalibrationAlpha(self, alpha: float) -> None: ...
    def setCamera(self, name: str) -> None: ...
    def setFps(self, fps: float) -> None: ...
    def setImageOrientation(self, imageOrientation: depthai.CameraImageOrientation) -> None: ...
    def setIsp3aFps(self, arg0: int) -> None: ...
    def setMeshSource(self, source: depthai.CameraProperties.WarpMeshSource) -> None: ...
    def setMeshStep(self, width: int, height: int) -> None: ...
    @overload
    def setPreviewSize(self, width: int, height: int) -> None: ...
    @overload
    def setPreviewSize(self, size: Tuple[int,int]) -> None: ...
    def setRawOutputPacked(self, packed: bool) -> None: ...
    @overload
    def setSize(self, width: int, height: int) -> None: ...
    @overload
    def setSize(self, size: Tuple[int,int]) -> None: ...
    @overload
    def setStillSize(self, width: int, height: int) -> None: ...
    @overload
    def setStillSize(self, size: Tuple[int,int]) -> None: ...
    @overload
    def setVideoSize(self, width: int, height: int) -> None: ...
    @overload
    def setVideoSize(self, size: Tuple[int,int]) -> None: ...
    @property
    def frameEvent(self) -> depthai.Node.Output: ...
    @property
    def initialControl(self) -> depthai.CameraControl: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputControl(self) -> depthai.Node.Input: ...
    @property
    def isp(self) -> depthai.Node.Output: ...
    @property
    def preview(self) -> depthai.Node.Output: ...
    @property
    def raw(self) -> depthai.Node.Output: ...
    @property
    def still(self) -> depthai.Node.Output: ...
    @property
    def video(self) -> depthai.Node.Output: ...

class ColorCamera(depthai.DeviceNode):
    class Properties:
        class ColorOrder:
            __members__: ClassVar[dict] = ...  # read-only
            BGR: ClassVar[depthai.ColorCameraProperties.ColorOrder] = ...
            RGB: ClassVar[depthai.ColorCameraProperties.ColorOrder] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class SensorResolution:
            __members__: ClassVar[dict] = ...  # read-only
            THE_1080_P: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_1200_P: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_1280X962: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_12_MP: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_1352X1012: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_13_MP: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_1440X1080: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_2000X1500: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_2024X1520: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_2028X1520: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_2104X1560: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_240X180: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_4000X3000: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_48_MP: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_4_K: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_5312X6000: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_5_MP: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_720_P: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_800_P: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class WarpMeshSource:
            __members__: ClassVar[dict] = ...  # read-only
            AUTO: ClassVar[depthai.ColorCameraProperties.WarpMeshSource] = ...
            CALIBRATION: ClassVar[depthai.ColorCameraProperties.WarpMeshSource] = ...
            NONE: ClassVar[depthai.ColorCameraProperties.WarpMeshSource] = ...
            URI: ClassVar[depthai.ColorCameraProperties.WarpMeshSource] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        boardSocket: depthai.CameraBoardSocket
        calibAlpha: float
        eventFilter: List[depthai.FrameEvent]
        fps: float
        imageOrientation: depthai.CameraImageOrientation
        initialControl: depthai.CameraControl
        isp3aFps: int
        ispScale: Any
        numFramesPoolIsp: int
        numFramesPoolPreview: int
        numFramesPoolRaw: int
        numFramesPoolStill: int
        numFramesPoolVideo: int
        previewHeight: int
        previewKeepAspectRatio: bool
        previewWidth: int
        resolution: depthai.ColorCameraProperties.SensorResolution
        sensorCropX: float
        sensorCropY: float
        stillHeight: int
        stillWidth: int
        videoHeight: int
        videoWidth: int
        warpMeshHeight: int
        warpMeshSource: depthai.ColorCameraProperties.WarpMeshSource
        warpMeshStepHeight: int
        warpMeshStepWidth: int
        warpMeshUri: str
        warpMeshWidth: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self) -> None: ...
    def build(self) -> ColorCamera: ...
    def getBoardSocket(self) -> depthai.CameraBoardSocket: ...
    def getCalibrationAlpha(self) -> float: ...
    def getCamId(self) -> int: ...
    def getCamera(self) -> str: ...
    def getColorOrder(self) -> depthai.ColorCameraProperties.ColorOrder: ...
    def getFp16(self) -> bool: ...
    def getFps(self) -> float: ...
    def getFrameEventFilter(self) -> List[depthai.FrameEvent]: ...
    def getImageOrientation(self) -> depthai.CameraImageOrientation: ...
    def getInterleaved(self) -> bool: ...
    def getIspHeight(self) -> int: ...
    def getIspNumFramesPool(self) -> int: ...
    def getIspSize(self) -> Tuple[int,int]: ...
    def getIspWidth(self) -> int: ...
    def getMeshSize(self) -> Tuple[int,int]: ...
    def getMeshSource(self) -> depthai.ColorCameraProperties.WarpMeshSource: ...
    def getMeshStep(self) -> Tuple[int,int]: ...
    def getPreviewHeight(self) -> int: ...
    def getPreviewKeepAspectRatio(self) -> bool: ...
    def getPreviewNumFramesPool(self) -> int: ...
    def getPreviewSize(self) -> Tuple[int,int]: ...
    def getPreviewWidth(self) -> int: ...
    def getRawNumFramesPool(self) -> int: ...
    def getResolution(self) -> depthai.ColorCameraProperties.SensorResolution: ...
    def getResolutionHeight(self) -> int: ...
    def getResolutionSize(self) -> Tuple[int,int]: ...
    def getResolutionWidth(self) -> int: ...
    def getSensorCrop(self) -> Tuple[float,float]: ...
    def getSensorCropX(self) -> float: ...
    def getSensorCropY(self) -> float: ...
    def getStillHeight(self) -> int: ...
    def getStillNumFramesPool(self) -> int: ...
    def getStillSize(self) -> Tuple[int,int]: ...
    def getStillWidth(self) -> int: ...
    def getVideoHeight(self) -> int: ...
    def getVideoNumFramesPool(self) -> int: ...
    def getVideoSize(self) -> Tuple[int,int]: ...
    def getVideoWidth(self) -> int: ...
    def getWaitForConfigInput(self) -> bool: ...
    def loadMeshData(self, warpMesh: List[int]) -> None: ...
    def sensorCenterCrop(self) -> None: ...
    def setBoardSocket(self, boardSocket: depthai.CameraBoardSocket) -> None: ...
    def setCalibrationAlpha(self, alpha: float) -> None: ...
    def setCamId(self, arg0: int) -> None: ...
    def setCamera(self, name: str) -> None: ...
    def setColorOrder(self, colorOrder: depthai.ColorCameraProperties.ColorOrder) -> None: ...
    def setFp16(self, fp16: bool) -> None: ...
    def setFps(self, fps: float) -> None: ...
    def setFrameEventFilter(self, events: List[depthai.FrameEvent]) -> None: ...
    def setImageOrientation(self, imageOrientation: depthai.CameraImageOrientation) -> None: ...
    def setInterleaved(self, interleaved: bool) -> None: ...
    def setIsp3aFps(self, arg0: int) -> None: ...
    def setIspNumFramesPool(self, arg0: int) -> None: ...
    @overload
    def setIspScale(self, numerator: int, denominator: int) -> None: ...
    @overload
    def setIspScale(self, scale: Tuple[int,int]) -> None: ...
    @overload
    def setIspScale(self, horizNum: int, horizDenom: int, vertNum: int, vertDenom: int) -> None: ...
    @overload
    def setIspScale(self, horizScale: Tuple[int,int], vertScale: Tuple[int,int]) -> None: ...
    def setMeshSize(self, width: int, height: int) -> None: ...
    def setMeshSource(self, source: depthai.ColorCameraProperties.WarpMeshSource) -> None: ...
    def setMeshStep(self, width: int, height: int) -> None: ...
    def setNumFramesPool(self, raw: int, isp: int, preview: int, video: int, still: int) -> None: ...
    def setPreviewKeepAspectRatio(self, keep: bool) -> None: ...
    def setPreviewNumFramesPool(self, arg0: int) -> None: ...
    @overload
    def setPreviewSize(self, width: int, height: int) -> None: ...
    @overload
    def setPreviewSize(self, size: Tuple[int,int]) -> None: ...
    def setRawNumFramesPool(self, arg0: int) -> None: ...
    def setRawOutputPacked(self, packed: bool) -> None: ...
    def setResolution(self, resolution: depthai.ColorCameraProperties.SensorResolution) -> None: ...
    def setSensorCrop(self, x: float, y: float) -> None: ...
    def setStillNumFramesPool(self, arg0: int) -> None: ...
    @overload
    def setStillSize(self, width: int, height: int) -> None: ...
    @overload
    def setStillSize(self, size: Tuple[int,int]) -> None: ...
    def setVideoNumFramesPool(self, arg0: int) -> None: ...
    @overload
    def setVideoSize(self, width: int, height: int) -> None: ...
    @overload
    def setVideoSize(self, size: Tuple[int,int]) -> None: ...
    def setWaitForConfigInput(self, wait: bool) -> None: ...
    @property
    def frameEvent(self) -> depthai.Node.Output: ...
    @property
    def initialControl(self) -> depthai.CameraControl: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputControl(self) -> depthai.Node.Input: ...
    @property
    def isp(self) -> depthai.Node.Output: ...
    @property
    def preview(self) -> depthai.Node.Output: ...
    @property
    def raw(self) -> depthai.Node.Output: ...
    @property
    def still(self) -> depthai.Node.Output: ...
    @property
    def video(self) -> depthai.Node.Output: ...

class DetectionNetwork(depthai.NodeGroup):
    def __init__(self, input: depthai.Node.Output, nnArchive: depthai.NNArchive, confidenceThreshold: float = ...) -> None: ...
    def build(self, input: depthai.Node.Output, nnArchive: depthai.NNArchive, confidenceThreshold: float = ...) -> DetectionNetwork: ...
    def getClasses(self) -> Optional[List[str]]: ...
    def getConfidenceThreshold(self) -> float: ...
    def getNumInferenceThreads(self) -> int: ...
    def setBackend(self, setBackend: str) -> None: ...
    def setBackendProperties(self, setBackendProperties: Dict[str,str]) -> None: ...
    @overload
    def setBlob(self, blob: depthai.OpenVINO.Blob) -> None: ...
    @overload
    def setBlob(self, path: Path) -> None: ...
    def setBlobPath(self, path: Path) -> None: ...
    def setConfidenceThreshold(self, thresh: float) -> None: ...
    def setNNArchive(self, arg0: depthai.NNArchive) -> None: ...
    def setNumInferenceThreads(self, numThreads: int) -> None: ...
    def setNumNCEPerInferenceThread(self, numNCEPerThread: int) -> None: ...
    def setNumPoolFrames(self, numFrames: int) -> None: ...
    def setNumShavesPerInferenceThread(self, numShavesPerInferenceThread: int) -> None: ...
    def setXmlModelPath(self, xmlModelPath: Path, binModelPath: Path = ...) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def outNetwork(self) -> depthai.Node.Output: ...
    @property
    def passthrough(self) -> depthai.Node.Output: ...

class DetectionParser(depthai.DeviceNode):
    class Properties:
        parser: depthai.DetectionParserOptions
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getAnchorMasks(self) -> Dict[str,List[int]]: ...
    def getAnchors(self) -> List[float]: ...
    def getConfidenceThreshold(self) -> float: ...
    def getCoordinateSize(self) -> int: ...
    def getIouThreshold(self) -> float: ...
    def getNNFamily(self) -> depthai.DetectionNetworkType: ...
    def getNumClasses(self) -> int: ...
    def getNumFramesPool(self) -> int: ...
    def setAnchorMasks(self, anchorMasks: Dict[str,List[int]]) -> None: ...
    @overload
    def setAnchors(self, anchors: List[List[List[float]]]) -> None: ...
    @overload
    def setAnchors(self, anchors: List[float]) -> None: ...
    @overload
    def setBlob(self, blob: depthai.OpenVINO.Blob) -> None: ...
    @overload
    def setBlob(self, path: Path) -> None: ...
    def setBlobPath(self, path: Path) -> None: ...
    def setConfidenceThreshold(self, thresh: float) -> None: ...
    def setCoordinateSize(self, coordinates: int) -> None: ...
    @overload
    def setInputImageSize(self, width: int, height: int) -> None: ...
    @overload
    def setInputImageSize(self, size: Tuple[int,int]) -> None: ...
    def setIouThreshold(self, thresh: float) -> None: ...
    def setNNFamily(self, type: depthai.DetectionNetworkType) -> None: ...
    def setNumClasses(self, numClasses: int) -> None: ...
    def setNumFramesPool(self, numFramesPool: int) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class EdgeDetector(depthai.DeviceNode):
    class Properties:
        initialConfig: depthai.EdgeDetectorConfig
        numFramesPool: int
        outputFrameSize: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getWaitForConfigInput(self) -> bool: ...
    def setMaxOutputFrameSize(self, arg0: int) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    def setWaitForConfigInput(self, wait: bool) -> None: ...
    @property
    def initialConfig(self) -> depthai.EdgeDetectorConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputImage(self) -> depthai.Node.Input: ...
    @property
    def outputImage(self) -> depthai.Node.Output: ...

class FeatureTracker(depthai.DeviceNode):
    class Properties:
        initialConfig: depthai.FeatureTrackerConfig
        numMemorySlices: int
        numShaves: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getWaitForConfigInput(self) -> bool: ...
    def setHardwareResources(self, numShaves: int, numMemorySlices: int) -> None: ...
    def setWaitForConfigInput(self, wait: bool) -> None: ...
    @property
    def initialConfig(self) -> depthai.FeatureTrackerConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputImage(self) -> depthai.Node.Input: ...
    @property
    def outputFeatures(self) -> depthai.Node.Output: ...
    @property
    def passthroughInputImage(self) -> depthai.Node.Output: ...

class HostNode(ThreadedHostNode):
    def link_args(self, *args) -> None: ...
    def __init__(self, *args) -> None: ...
    __init_subclass__: ClassVar[method] = ...
    def __init__(self) -> None: ...
    def processGroup(self, arg0: depthai.MessageGroup) -> depthai.Buffer: ...
    def runSyncingOnDevice(self) -> None: ...
    def runSyncingOnHost(self) -> None: ...
    def sendProcessingToPipeline(self, arg0: bool) -> None: ...
    @property
    def inputs(self) -> depthai.Node.InputMap: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class IMU(depthai.DeviceNode):
    class Properties:
        batchReportThreshold: int
        enableFirmwareUpdate: Optional[bool]
        imuSensors: List[depthai.IMUSensorConfig]
        maxBatchReports: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def enableFirmwareUpdate(self, arg0: bool) -> None: ...
    @overload
    def enableIMUSensor(self, sensorConfig: depthai.IMUSensorConfig) -> None: ...
    @overload
    def enableIMUSensor(self, sensorConfigs: List[depthai.IMUSensorConfig]) -> None: ...
    @overload
    def enableIMUSensor(self, sensor: depthai.IMUSensor, reportRate: int) -> None: ...
    @overload
    def enableIMUSensor(self, sensors: List[depthai.IMUSensor], reportRate: int) -> None: ...
    def getBatchReportThreshold(self) -> int: ...
    def getMaxBatchReports(self) -> int: ...
    def setBatchReportThreshold(self, batchReportThreshold: int) -> None: ...
    def setMaxBatchReports(self, maxBatchReports: int) -> None: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class ImageManip(depthai.DeviceNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def getWaitForConfigInput(self) -> bool: ...
    def setCenterCrop(self, arg0: float, arg1: float) -> None: ...
    def setCropRect(self, arg0: float, arg1: float, arg2: float, arg3: float) -> None: ...
    def setFrameType(self, arg0: depthai.ImgFrame.Type) -> None: ...
    def setHorizontalFlip(self, arg0: bool) -> None: ...
    def setKeepAspectRatio(self, arg0: bool) -> None: ...
    def setMaxOutputFrameSize(self, arg0: int) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    def setResize(self, arg0: int, arg1: int) -> None: ...
    def setResizeThumbnail(self, arg0: int, arg1: int, arg2: int, arg3: int, arg4: int) -> None: ...
    def setWaitForConfigInput(self, wait: bool) -> None: ...
    @overload
    def setWarpMesh(self, arg0: List[depthai.Point2f], arg1: int, arg2: int) -> None: ...
    @overload
    def setWarpMesh(self, arg0: List[Tuple[float,float]], arg1: int, arg2: int) -> None: ...
    @property
    def initialConfig(self) -> depthai.ImageManipConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputImage(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class MessageDemux(depthai.DeviceNode):
    class Properties:
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def outputs(self) -> depthai.Node.OutputMap: ...

class MobileNetDetectionNetwork(DetectionNetwork):
    def __init__(self, *args, **kwargs) -> None: ...
    def build(self) -> MobileNetDetectionNetwork: ...

class MobileNetSpatialDetectionNetwork(SpatialDetectionNetwork):
    def __init__(self, *args, **kwargs) -> None: ...
    def build(self) -> MobileNetSpatialDetectionNetwork: ...

class MonoCamera(depthai.DeviceNode):
    class Properties:
        class SensorResolution:
            __members__: ClassVar[dict] = ...  # read-only
            THE_1200_P: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            THE_4000X3000: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            THE_400_P: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            THE_4224X3136: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            THE_480_P: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            THE_720_P: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            THE_800_P: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        boardSocket: depthai.CameraBoardSocket
        eventFilter: List[depthai.FrameEvent]
        fps: float
        initialControl: depthai.CameraControl
        isp3aFps: int
        numFramesPool: int
        numFramesPoolRaw: int
        resolution: depthai.MonoCameraProperties.SensorResolution
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getBoardSocket(self) -> depthai.CameraBoardSocket: ...
    def getCamId(self) -> int: ...
    def getCamera(self) -> str: ...
    def getFps(self) -> float: ...
    def getFrameEventFilter(self) -> List[depthai.FrameEvent]: ...
    def getImageOrientation(self) -> depthai.CameraImageOrientation: ...
    def getNumFramesPool(self) -> int: ...
    def getRawNumFramesPool(self) -> int: ...
    def getResolution(self) -> depthai.MonoCameraProperties.SensorResolution: ...
    def getResolutionHeight(self) -> int: ...
    def getResolutionSize(self) -> Tuple[int,int]: ...
    def getResolutionWidth(self) -> int: ...
    def setBoardSocket(self, boardSocket: depthai.CameraBoardSocket) -> None: ...
    def setCamId(self, arg0: int) -> None: ...
    def setCamera(self, name: str) -> None: ...
    def setFps(self, fps: float) -> None: ...
    def setFrameEventFilter(self, events: List[depthai.FrameEvent]) -> None: ...
    def setImageOrientation(self, imageOrientation: depthai.CameraImageOrientation) -> None: ...
    def setIsp3aFps(self, arg0: int) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    def setRawNumFramesPool(self, arg0: int) -> None: ...
    def setRawOutputPacked(self, packed: bool) -> None: ...
    def setResolution(self, resolution: depthai.MonoCameraProperties.SensorResolution) -> None: ...
    @property
    def frameEvent(self) -> depthai.Node.Output: ...
    @property
    def initialControl(self) -> depthai.CameraControl: ...
    @property
    def inputControl(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def raw(self) -> depthai.Node.Output: ...

class NeuralNetwork(depthai.DeviceNode):
    class Properties:
        blobSize: Optional[int]
        blobUri: str
        numFrames: int
        numNCEPerThread: int
        numThreads: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getNumInferenceThreads(self) -> int: ...
    def setBackend(self, setBackend: str) -> None: ...
    def setBackendProperties(self, setBackendProperties: Dict[str,str]) -> None: ...
    @overload
    def setBlob(self, blob: depthai.OpenVINO.Blob) -> None: ...
    @overload
    def setBlob(self, path: Path) -> None: ...
    def setBlobPath(self, path: Path) -> None: ...
    def setNumInferenceThreads(self, numThreads: int) -> None: ...
    def setNumNCEPerInferenceThread(self, numNCEPerThread: int) -> None: ...
    def setNumPoolFrames(self, numFrames: int) -> None: ...
    def setNumShavesPerInferenceThread(self, numShavesPerInferenceThread: int) -> None: ...
    def setXmlModelPath(self, xmlModelPath: Path, binModelPath: Path = ...) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def inputs(self) -> depthai.Node.InputMap: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def passthrough(self) -> depthai.Node.Output: ...
    @property
    def passthroughs(self) -> depthai.Node.OutputMap: ...

class ObjectTracker(depthai.DeviceNode):
    class Properties:
        detectionLabelsToTrack: List[int]
        maxObjectsToTrack: int
        trackerIdAssignmentPolicy: depthai.TrackerIdAssignmentPolicy
        trackerThreshold: float
        trackerType: depthai.TrackerType
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def setDetectionLabelsToTrack(self, labels: List[int]) -> None: ...
    def setMaxObjectsToTrack(self, maxObjectsToTrack: int) -> None: ...
    def setTrackerIdAssignmentPolicy(self, type: depthai.TrackerIdAssignmentPolicy) -> None: ...
    def setTrackerThreshold(self, threshold: float) -> None: ...
    def setTrackerType(self, type: depthai.TrackerType) -> None: ...
    def setTrackingPerClass(self, trackingPerClass: bool) -> None: ...
    @property
    def inputDetectionFrame(self) -> depthai.Node.Input: ...
    @property
    def inputDetections(self) -> depthai.Node.Input: ...
    @property
    def inputTrackerFrame(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def passthroughDetectionFrame(self) -> depthai.Node.Output: ...
    @property
    def passthroughDetections(self) -> depthai.Node.Output: ...
    @property
    def passthroughTrackerFrame(self) -> depthai.Node.Output: ...

class PointCloud(depthai.DeviceNode):
    class Properties:
        initialConfig: depthai.PointCloudConfig
        numFramesPool: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    @property
    def initialConfig(self) -> depthai.PointCloudConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputDepth(self) -> depthai.Node.Input: ...
    @property
    def outputPointCloud(self) -> depthai.Node.Output: ...
    @property
    def passthroughDepth(self) -> depthai.Node.Output: ...

class Record(ThreadedHostNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def setCompressionLevel(self, compressionLevel) -> Record: ...
    def setRecordFile(self, recordFile: str) -> Record: ...
    @property
    def input(self) -> depthai.Node.Input: ...

class Replay(ThreadedHostNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def setFps(self, fps: float) -> Replay: ...
    def setOutFrameType(self, frameType: depthai.ImgFrame.Type) -> Replay: ...
    def setReplayFile(self, replayFile: str) -> Replay: ...
    def setReplayVideo(self, replayVideo: str) -> Replay: ...
    @overload
    def setSize(self, width: int, height: int) -> Replay: ...
    @overload
    def setSize(self, size: Tuple[int,int]) -> Replay: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class SPIIn(depthai.DeviceNode):
    class Properties:
        busId: int
        maxDataSize: int
        numFrames: int
        streamName: str
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getBusId(self) -> int: ...
    def getMaxDataSize(self) -> int: ...
    def getNumFrames(self) -> int: ...
    def getStreamName(self) -> str: ...
    def setBusId(self, id: int) -> None: ...
    def setMaxDataSize(self, maxDataSize: int) -> None: ...
    def setNumFrames(self, numFrames: int) -> None: ...
    def setStreamName(self, name: str) -> None: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class SPIOut(depthai.DeviceNode):
    class Properties:
        busId: int
        streamName: str
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def setBusId(self, id: int) -> None: ...
    def setStreamName(self, name: str) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...

class Script(depthai.DeviceNode):
    class Properties:
        processor: depthai.ProcessorType
        scriptName: str
        scriptUri: str
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getProcessor(self) -> depthai.ProcessorType: ...
    def getScriptName(self) -> str: ...
    def setProcessor(self, arg0: depthai.ProcessorType) -> None: ...
    @overload
    def setScript(self, script: str, name: str = ...) -> None: ...
    @overload
    def setScript(self, data: List[int], name: str = ...) -> None: ...
    @overload
    def setScriptPath(self, arg0: Path, arg1: str) -> None: ...
    @overload
    def setScriptPath(self, path: Path, name: str = ...) -> None: ...
    @property
    def inputs(self) -> depthai.Node.InputMap: ...
    @property
    def outputs(self) -> depthai.Node.OutputMap: ...

class SpatialDetectionNetwork(depthai.DeviceNode):
    class Properties:
        depthThresholds: depthai.SpatialLocationCalculatorConfigThresholds
        detectedBBScaleFactor: float
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def build(self) -> SpatialDetectionNetwork: ...
    def getClasses(self) -> Optional[List[str]]: ...
    def getConfidenceThreshold(self) -> float: ...
    def getNumInferenceThreads(self) -> int: ...
    def setBackend(self, setBackend: str) -> None: ...
    def setBackendProperties(self, setBackendProperties: Dict[str,str]) -> None: ...
    @overload
    def setBlob(self, blob: depthai.OpenVINO.Blob) -> None: ...
    @overload
    def setBlob(self, path: Path) -> None: ...
    def setBlobPath(self, path: Path) -> None: ...
    def setBoundingBoxScaleFactor(self, scaleFactor: float) -> None: ...
    def setConfidenceThreshold(self, thresh: float) -> None: ...
    def setDepthLowerThreshold(self, lowerThreshold: int) -> None: ...
    def setDepthUpperThreshold(self, upperThreshold: int) -> None: ...
    def setNNArchive(self, arg0: depthai.NNArchive) -> None: ...
    def setNumInferenceThreads(self, numThreads: int) -> None: ...
    def setNumNCEPerInferenceThread(self, numNCEPerThread: int) -> None: ...
    def setNumPoolFrames(self, numFrames: int) -> None: ...
    def setNumShavesPerInferenceThread(self, numShavesPerInferenceThread: int) -> None: ...
    def setSpatialCalculationAlgorithm(self, calculationAlgorithm: depthai.SpatialLocationCalculatorAlgorithm) -> None: ...
    def setXmlModelPath(self, xmlModelPath: Path, binModelPath: Path = ...) -> None: ...
    @property
    def boundingBoxMapping(self) -> depthai.Node.Output: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def inputDepth(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def outNetwork(self) -> depthai.Node.Output: ...
    @property
    def passthrough(self) -> depthai.Node.Output: ...
    @property
    def passthroughDepth(self) -> depthai.Node.Output: ...
    @property
    def spatialLocationCalculatorOutput(self) -> depthai.Node.Output: ...

class SpatialLocationCalculator(depthai.DeviceNode):
    class Properties:
        roiConfig: depthai.SpatialLocationCalculatorConfig
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getWaitForConfigInput(self) -> bool: ...
    def setWaitForConfigInput(self, wait: bool) -> None: ...
    @property
    def initialConfig(self) -> depthai.SpatialLocationCalculatorConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputDepth(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def passthroughDepth(self) -> depthai.Node.Output: ...

class StereoDepth(depthai.DeviceNode):
    class PresetMode:
        __members__: ClassVar[dict] = ...  # read-only
        HIGH_ACCURACY: ClassVar[StereoDepth.PresetMode] = ...
        HIGH_DENSITY: ClassVar[StereoDepth.PresetMode] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class Properties:
        class RectificationMesh:
            meshLeftUri: str
            meshRightUri: str
            meshSize: Optional[int]
            stepHeight: int
            stepWidth: int
            def __init__(self, *args, **kwargs) -> None: ...
        alphaScaling: Optional[float]
        baseline: Optional[float]
        depthAlignCamera: depthai.CameraBoardSocket
        depthAlignmentUseSpecTranslation: Optional[bool]
        disparityToDepthUseSpecTranslation: Optional[bool]
        enableRectification: bool
        enableRuntimeStereoModeSwitch: bool
        focalLength: Optional[float]
        focalLengthFromCalibration: bool
        height: Optional[int]
        initialConfig: depthai.StereoDepthConfig
        mesh: depthai.StereoDepthProperties.RectificationMesh
        numFramesPool: int
        numPostProcessingMemorySlices: int
        numPostProcessingShaves: int
        outHeight: Optional[int]
        outKeepAspectRatio: bool
        outWidth: Optional[int]
        rectificationUseSpecTranslation: Optional[bool]
        rectifyEdgeFillColor: int
        useHomographyRectification: Optional[bool]
        width: Optional[int]
        def __init__(self, *args, **kwargs) -> None: ...
    @overload
    def __init__(self, left: depthai.Node.Output, right: depthai.Node.Output, presetMode: StereoDepth.PresetMode = ...) -> None: ...
    @overload
    def __init__(self, autoCreateCameras: bool, presetMode: StereoDepth.PresetMode = ...) -> None: ...
    @overload
    def build(self, left: depthai.Node.Output, right: depthai.Node.Output, presetMode: StereoDepth.PresetMode = ...) -> StereoDepth: ...
    @overload
    def build(self, autoCreateCameras: bool, presetMode: StereoDepth.PresetMode = ...) -> StereoDepth: ...
    def enableDistortionCorrection(self, arg0: bool) -> None: ...
    def getMaxDisparity(self) -> float: ...
    def loadMeshData(self, dataLeft: List[int], dataRight: List[int]) -> None: ...
    def loadMeshFiles(self, pathLeft: Path, pathRight: Path) -> None: ...
    def setAlphaScaling(self, arg0: float) -> None: ...
    def setBaseline(self, arg0: float) -> None: ...
    def setConfidenceThreshold(self, arg0: int) -> None: ...
    def setCustomPixelDescriptors(self, arg0: bool) -> None: ...
    def setDefaultProfilePreset(self, arg0: StereoDepth.PresetMode) -> None: ...
    @overload
    def setDepthAlign(self, align: depthai.StereoDepthConfig.AlgorithmControl.DepthAlign) -> None: ...
    @overload
    def setDepthAlign(self, camera: depthai.CameraBoardSocket) -> None: ...
    def setDepthAlignmentUseSpecTranslation(self, arg0: bool) -> None: ...
    def setDisparityToDepthUseSpecTranslation(self, arg0: bool) -> None: ...
    def setEmptyCalibration(self) -> None: ...
    def setExtendedDisparity(self, enable: bool) -> None: ...
    def setFocalLength(self, arg0: float) -> None: ...
    def setFocalLengthFromCalibration(self, arg0: bool) -> None: ...
    @overload
    def setInputResolution(self, width: int, height: int) -> None: ...
    @overload
    def setInputResolution(self, resolution: Tuple[int,int]) -> None: ...
    def setLeftRightCheck(self, enable: bool) -> None: ...
    def setMedianFilter(self, arg0: depthai.MedianFilter) -> None: ...
    def setMeshStep(self, width: int, height: int) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    def setOutputDepth(self, arg0: bool) -> None: ...
    def setOutputKeepAspectRatio(self, keep: bool) -> None: ...
    def setOutputRectified(self, arg0: bool) -> None: ...
    def setOutputSize(self, width: int, height: int) -> None: ...
    def setPostProcessingHardwareResources(self, arg0: int, arg1: int) -> None: ...
    def setRectification(self, enable: bool) -> None: ...
    def setRectificationUseSpecTranslation(self, arg0: bool) -> None: ...
    def setRectifyEdgeFillColor(self, color: int) -> None: ...
    def setRectifyMirrorFrame(self, arg0: bool) -> None: ...
    def setRuntimeModeSwitch(self, arg0: bool) -> None: ...
    def setSubpixel(self, enable: bool) -> None: ...
    def setSubpixelFractionalBits(self, subpixelFractionalBits: int) -> None: ...
    def setVerticalStereo(self, arg0: bool) -> None: ...
    def useHomographyRectification(self, arg0: bool) -> None: ...
    @property
    def confidenceMap(self) -> depthai.Node.Output: ...
    @property
    def debugDispCostDump(self) -> depthai.Node.Output: ...
    @property
    def debugDispLrCheckIt1(self) -> depthai.Node.Output: ...
    @property
    def debugDispLrCheckIt2(self) -> depthai.Node.Output: ...
    @property
    def debugExtDispLrCheckIt1(self) -> depthai.Node.Output: ...
    @property
    def debugExtDispLrCheckIt2(self) -> depthai.Node.Output: ...
    @property
    def depth(self) -> depthai.Node.Output: ...
    @property
    def disparity(self) -> depthai.Node.Output: ...
    @property
    def initialConfig(self) -> depthai.StereoDepthConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputLeftPixelDescriptor(self) -> depthai.Node.Input: ...
    @property
    def inputRightPixelDescriptor(self) -> depthai.Node.Input: ...
    @property
    def left(self) -> depthai.Node.Input: ...
    @property
    def outConfig(self) -> depthai.Node.Output: ...
    @property
    def pixelDescriptorsLeft(self) -> depthai.Node.Output: ...
    @property
    def pixelDescriptorsRight(self) -> depthai.Node.Output: ...
    @property
    def rectifiedLeft(self) -> depthai.Node.Output: ...
    @property
    def rectifiedRight(self) -> depthai.Node.Output: ...
    @property
    def right(self) -> depthai.Node.Input: ...
    @property
    def syncedLeft(self) -> depthai.Node.Output: ...
    @property
    def syncedRight(self) -> depthai.Node.Output: ...

class Sync(depthai.DeviceNode):
    class Properties:
        syncAttempts: int
        syncThresholdNs: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getSyncAttempts(self) -> int: ...
    def getSyncThreshold(self) -> datetime.timedelta: ...
    def runOnHost(self) -> bool: ...
    def setRunOnHost(self, runOnHost: bool) -> None: ...
    def setSyncAttempts(self, maxDataSize: int) -> None: ...
    def setSyncThreshold(self, syncThreshold: datetime.timedelta) -> None: ...
    @property
    def inputs(self) -> depthai.Node.InputMap: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class SystemLogger(depthai.DeviceNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def getRate(self) -> float: ...
    def setRate(self, hz: float) -> None: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class ThreadedHostNode(depthai.ThreadedNode):
    def __init__(self) -> None: ...
    def run(self) -> None: ...

class ToF(depthai.DeviceNode):
    class Properties:
        initialConfig: depthai.ToFConfig
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    @property
    def amplitude(self) -> depthai.Node.Output: ...
    @property
    def depth(self) -> depthai.Node.Output: ...
    @property
    def error(self) -> depthai.Node.Output: ...
    @property
    def initialConfig(self) -> depthai.ToFConfig: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def intensity(self) -> depthai.Node.Output: ...

class UVC(depthai.DeviceNode):
    class Properties:
        gpioInit: Dict[int,int]
        gpioStreamOff: Dict[int,int]
        gpioStreamOn: Dict[int,int]
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, USBVideoClass) -> Any: ...
    def setGpiosOnInit(self, list: Dict[int,int]) -> None: ...
    def setGpiosOnStreamOff(self, list: Dict[int,int]) -> None: ...
    def setGpiosOnStreamOn(self, list: Dict[int,int]) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...

class VideoEncoder(depthai.DeviceNode):
    class Properties:
        class Profile:
            __members__: ClassVar[dict] = ...  # read-only
            H264_BASELINE: ClassVar[depthai.VideoEncoderProperties.Profile] = ...
            H264_HIGH: ClassVar[depthai.VideoEncoderProperties.Profile] = ...
            H264_MAIN: ClassVar[depthai.VideoEncoderProperties.Profile] = ...
            H265_MAIN: ClassVar[depthai.VideoEncoderProperties.Profile] = ...
            MJPEG: ClassVar[depthai.VideoEncoderProperties.Profile] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class RateControlMode:
            __members__: ClassVar[dict] = ...  # read-only
            CBR: ClassVar[depthai.VideoEncoderProperties.RateControlMode] = ...
            VBR: ClassVar[depthai.VideoEncoderProperties.RateControlMode] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        bitrate: int
        keyframeFrequency: int
        maxBitrate: int
        numBFrames: int
        numFramesPool: int
        outputFrameSize: int
        profile: depthai.VideoEncoderProperties.Profile
        quality: int
        rateCtrlMode: depthai.VideoEncoderProperties.RateControlMode
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, input: depthai.Node.Output, bitrate: float = ..., frameRate: float = ..., profile: depthai.VideoEncoderProperties.Profile = ..., keyframeFrequency: int = ..., lossless: bool = ..., quality: int = ...) -> None: ...
    def build(self, input: depthai.Node.Output, bitrate: float = ..., frameRate: float = ..., profile: depthai.VideoEncoderProperties.Profile = ..., keyframeFrequency: int = ..., lossless: bool = ..., quality: int = ...) -> VideoEncoder: ...
    def getBitrate(self) -> int: ...
    def getBitrateKbps(self) -> int: ...
    def getFrameRate(self) -> float: ...
    def getHeight(self) -> int: ...
    def getKeyframeFrequency(self) -> int: ...
    def getLossless(self) -> bool: ...
    def getMaxOutputFrameSize(self) -> int: ...
    def getNumBFrames(self) -> int: ...
    def getNumFramesPool(self) -> int: ...
    def getProfile(self) -> depthai.VideoEncoderProperties.Profile: ...
    def getQuality(self) -> int: ...
    def getRateControlMode(self) -> depthai.VideoEncoderProperties.RateControlMode: ...
    def getSize(self) -> Tuple[int,int]: ...
    def getWidth(self) -> int: ...
    def setBitrate(self, bitrate: int) -> None: ...
    def setBitrateKbps(self, bitrateKbps: int) -> None: ...
    @overload
    def setDefaultProfilePreset(self, fps: float, profile: depthai.VideoEncoderProperties.Profile) -> None: ...
    @overload
    def setDefaultProfilePreset(self, arg0: int, arg1: int, arg2: float, arg3: depthai.VideoEncoderProperties.Profile) -> None: ...
    @overload
    def setDefaultProfilePreset(self, arg0: Tuple[int,int], arg1: float, arg2: depthai.VideoEncoderProperties.Profile) -> None: ...
    def setFrameRate(self, frameRate: float) -> None: ...
    def setKeyframeFrequency(self, freq: int) -> None: ...
    def setLossless(self, arg0: bool) -> None: ...
    def setMaxOutputFrameSize(self, maxFrameSize: int) -> None: ...
    def setNumBFrames(self, numBFrames: int) -> None: ...
    def setNumFramesPool(self, frames: int) -> None: ...
    @overload
    def setProfile(self, profile: depthai.VideoEncoderProperties.Profile) -> None: ...
    @overload
    def setProfile(self, arg0: Tuple[int,int], arg1: depthai.VideoEncoderProperties.Profile) -> None: ...
    @overload
    def setProfile(self, arg0: int, arg1: int, arg2: depthai.VideoEncoderProperties.Profile) -> None: ...
    def setQuality(self, quality: int) -> None: ...
    def setRateControlMode(self, mode: depthai.VideoEncoderProperties.RateControlMode) -> None: ...
    @property
    def bitstream(self) -> depthai.Node.Output: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class Warp(depthai.DeviceNode):
    class Properties:
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getHwIds(self) -> List[int]: ...
    def getInterpolation(self) -> depthai.Interpolation: ...
    def setHwIds(self, arg0: List[int]) -> None: ...
    def setInterpolation(self, arg0: depthai.Interpolation) -> None: ...
    def setMaxOutputFrameSize(self, arg0: int) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    @overload
    def setOutputSize(self, arg0: int, arg1: int) -> None: ...
    @overload
    def setOutputSize(self, arg0: Tuple[int,int]) -> None: ...
    @overload
    def setWarpMesh(self, arg0: List[depthai.Point2f], arg1: int, arg2: int) -> None: ...
    @overload
    def setWarpMesh(self, arg0: List[Tuple[float,float]], arg1: int, arg2: int) -> None: ...
    @property
    def inputImage(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class XLinkIn(depthai.DeviceNode):
    class Properties:
        maxDataSize: int
        numFrames: int
        streamName: str
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getMaxDataSize(self) -> int: ...
    def getNumFrames(self) -> int: ...
    def getStreamName(self) -> str: ...
    def setMaxDataSize(self, maxDataSize: int) -> None: ...
    def setNumFrames(self, numFrames: int) -> None: ...
    def setStreamName(self, streamName: str) -> None: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class XLinkOut(depthai.DeviceNode):
    class Properties:
        maxFpsLimit: float
        metadataOnly: bool
        streamName: str
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getFpsLimit(self) -> float: ...
    def getMetadataOnly(self) -> bool: ...
    def getStreamName(self) -> str: ...
    def setFpsLimit(self, fpsLimit: float) -> None: ...
    def setMetadataOnly(self, arg0: bool) -> None: ...
    def setStreamName(self, streamName: str) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...

class YoloDetectionNetwork(DetectionNetwork):
    def __init__(self, *args, **kwargs) -> None: ...
    def build(self) -> YoloDetectionNetwork: ...
    def getAnchorMasks(self) -> Dict[str,List[int]]: ...
    def getAnchors(self) -> List[float]: ...
    def getCoordinateSize(self) -> int: ...
    def getIouThreshold(self) -> float: ...
    def getNumClasses(self) -> int: ...
    def setAnchorMasks(self, anchorMasks: Dict[str,List[int]]) -> None: ...
    def setCoordinateSize(self, coordinates: int) -> None: ...
    def setIouThreshold(self, thresh: float) -> None: ...
    def setNumClasses(self, numClasses: int) -> None: ...

class YoloSpatialDetectionNetwork(SpatialDetectionNetwork):
    def __init__(self, *args, **kwargs) -> None: ...
    def build(self) -> YoloSpatialDetectionNetwork: ...
    def getAnchorMasks(self) -> Dict[str,List[int]]: ...
    def getAnchors(self) -> List[float]: ...
    def getCoordinateSize(self) -> int: ...
    def getIouThreshold(self) -> float: ...
    def getNumClasses(self) -> int: ...
    def setAnchorMasks(self, anchorMasks: Dict[str,List[int]]) -> None: ...
    def setAnchors(self, anchors: List[float]) -> None: ...
    def setCoordinateSize(self, coordinates: int) -> None: ...
    def setIouThreshold(self, thresh: float) -> None: ...
    def setNumClasses(self, numClasses: int) -> None: ...
